<?php

namespace Factory;

/*******************************************************************************
NOME
 	Pebbian Service
 
DESCRIÇÃO
 	Integração  do webservice  da Pebbian  com outros webservices como WordPress
	consultando e  retornando dados, inserindo, alterando e chamando procedures.
 	
CRIAÇÃO
	20/03/2016 - Sérgio Pow
	
COLABORAÇÃO
	Mateus Freire
	João Faghner
  
*******************************************************************************/

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Teknisa\Libs\Util\Libraries\PHPMailer;
use Teknisa\Libs\Util\Libraries\SMTP;
use \Util\mail_template;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\Libs\Util\Address;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\ORM\Platform\OraclePlatform;
use Doctrine\DBAL\DriverManager;
use Exception; 
class PedidoFactory {
    
    protected $connection;
    protected $address;
    
    public function __construct(Environment $environment, NewCode $newCode, EntityManager $entityManager)  {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->newCode = $newCode;
        $this->entityManager = $entityManager;
    }
    
	/* 
    * Busca parametros para montar xml de conexão com banco de dados
    */
    private function getConnectionParams($row) {
		$connectionParams = [];
		$connectionParams['driver'] = 'oci8';
		$connectionParams['driverClass'] = '\Zeedhi\Framework\DBAL\Driver\OCI8\Driver';
		$connectionParams['charset'] = 'AL32UTF8';
		
		$connectionParams['user'] = $row['USER'];
		$connectionParams['password'] = $row['CONN'];
		$connectionParams['host'] = $row['HOST'];
		$connectionParams['port'] = $row['PORT'];
		$connectionParams['dbname'] = $row['DBNAME'];
		
		$connectionParams['service'] =  $row['SERVICE'];
		$connectionParams['isEncrypted'] =  $row['ISENCRYPTED'];
		$connectionParams['useVpd'] =  $row['USEVPD'];
		$connectionParams['vpdPassword'] =  $row['VPDPASSWORD'];
		$connectionParams['vpdWithWallet'] =  $row['VPDWITHWALLET'];
		
		$connectionParams['sessionMode'] = '';
		$connectionParams['sessionMode'] = $connectionParams['sessionMode'] == ''? null : $connectionParams['sessionMode'];
		$connectionParams['platform'] = new OraclePlatform();
    	return $connectionParams;
    }
    
	/* 
    * Monta xml de conexão com banco de dados
    */
    private function buildVPD($connectionParams, $NRORG) {
    	if($NRORG && isset($connectionParams['useVpd']) && $connectionParams['useVpd'] == 'true') {
            if(isset($connectionParams['vpdWithWallet']) && $connectionParams['vpdWithWallet'] == 'true') {
                unset($connectionParams['host']);
                unset($connectionParams['port']);
                $connectionParams['user'] = '/';
                $connectionParams['password'] = '';
                $connectionParams['dbname'] = 'USR_ORG_' . $NRORG;
                $connectionParams['sessionMode'] = -2147483648;
            } else {
                $connectionParams['user'] = 'USR_ORG_' . $NRORG;
                $connectionParams['password'] = $connectionParams['vpdPassword'];
                if(isset($connectionParams['isWallet']) && $connectionParams['isWallet'] == 'true') {
                    $connectionParams['dbname'] = isset($connectionParams['vpdDBNAME'])
                        ? $connectionParams['vpdDBNAME']
                        : $connectionParams['vpdDBName'];
                    $connectionParams['host'] = $connectionParams['vpdHost'];
                    $connectionParams['port'] = $connectionParams['vpdPort'];
                    $connectionParams['service'] = $connectionParams['vpdService'];
                    unset($connectionParams['sessionMode']);
                }
            }
        }
        
        return $connectionParams;
    }
    
	/*
	* Trata password para quando for criptografado ou se usa wallet
	*/
    private function buildPassword($connectionParams) {
        if(empty($connectionParams["password"])) {
            $connectionParams["password"] = '';
        } else if(isset($connectionParams["isEncrypted"]) && $connectionParams["isEncrypted"] == 'true') {
            $connectionParams["password"] = $this->decrypt($connectionParams["password"]);
        }
        return $connectionParams;
    }
    
    private function encrypt($text){
        return trim(
            base64_encode(
                mcrypt_encrypt(
                    MCRYPT_RIJNDAEL_256,
                    str_pad("zeedhi", 32, "\0"),
                    $text,
                    MCRYPT_MODE_ECB,
                    mcrypt_create_iv(mcrypt_get_iv_size(MCRYPT_RIJNDAEL_256, MCRYPT_MODE_ECB), MCRYPT_RAND)
                )
            )
        );
    }
    
    private function decrypt($text) {
        return trim(
            mcrypt_decrypt(
                MCRYPT_RIJNDAEL_256,
                str_pad("zeedhi", 32, "\0"),
                base64_decode($text),
                MCRYPT_MODE_ECB,
                mcrypt_create_iv(mcrypt_get_iv_size(MCRYPT_RIJNDAEL_256, MCRYPT_MODE_ECB), MCRYPT_RAND)
            )
        );
    }
    
    private function createDriver() {
    	$driver = \Doctrine\ORM\Tools\Setup::createXMLMetadataConfiguration([]);
    	
    	return $driver;
    }
    
    private function getConnection($row) {
		$connectionParams = $this->getConnectionParams($row);
		
		if(array_key_exists('NRORG', $row))
			$NRORG = $row['NRORG'];
		else
			throw new \Exception('NRORG column is required.');

		$connectionParams = $this->buildVPD($connectionParams, $NRORG);
		
		$connectionParams = $this->buildPassword($connectionParams);
		
		$driver = $this->createDriver();
		return DriverManager::getConnection($connectionParams, $driver, null);
    }
    
    public function connect($response, $row) {
		$query = "SELECT * FROM PEDIDOWEB";
		try {
			
			if(isset($row['SQL'])){
				$this->getConnection($row)->executeUpdate($row['SQL'], array());
				$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("response", array('message' => 'done!')));
			}else{
				$pedidoweb = $this->getConnection($row)->fetchAll($query, array());
				$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("pedidoweb", $pedidoweb));
			}
			
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			
		}
    }
        
/*******************************************************************************
	Config      é      a      requisição    de    configuração   do  webservice.
	 
	Recebe como parâmetros  o  número  da  organização e o número do webservice.
	
	Retorna  um  array  com  o número da organização, o número do webservice,  a
	descrição do webservice, a  url  do  webservice,   a  chave  e  a  senha  de 
	autentificação  do  cliente  e  a tabela  de  preço  que  será  utilizada no
	webservice.
*******************************************************************************/
    
    public function config($response, $row) {
		$query = <<<SQL
			SELECT NRORG, NRSEQWEBSERVICE, DSWEBSERVICE, DSWEBSERVICEURL,
			       DSCHAVECLIENTE, DSSENHACLIENTE, CDPRECOBASE, CDOPERADOR,
			       CDMODPGTO, IDTIPOOPERWEB, CDTIPOOPERWEB, CDFILIAL,
			       CDVENDEDOR
			  FROM PEDIDOWEB
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			 ORDER BY NRSEQWEBSERVICE
SQL;
		try {
			$config = $this->getConnection($row)->fetchAll($query, array(':P_NRORG'           => $row['NRORG'],
																':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE']));
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("config", $config));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			
		}
    }
    
/*******************************************************************************
	buscarProduto é  a  requisição   de   busca  de  produtos.  É  composta  por
	produtos  ativos e que possuem preço vigente	na tabela de preço utilizada 
	pelo webservice.
	
	Recebe  como parêmtros  o número da  organização,  o número do webservice, o
	código da tabela  de  preço  utilizada  e  o  código  do  produto (ALL).
	
	Retorna um  array  com  o  número da organização, o número do  webservice, o
	código,   o  código   de   árvore,   o  nome,  a  unidade,  o preço, o preço 
	promocional (se houver), o resumo e a descrição do produto.
	
	Para   cada   produto   retorna  um array com as fotos do produto contendo o 
	código   do   produto,  o  número  sequencial  da  foto, o link da foto e um 
	identificador caso a foto seja a foto principal ou não.
*******************************************************************************/
    
    public function buscarProduto($response, $row) {
		$query = <<<SQL
			SELECT PW.NRORG, PW.NRSEQWEBSERVICE, PR.CDPRODUTO, PR.CDARVPROD,
			       PR.NMPRODUTO, PR.SGUNIDADE, IB.VRITEPREBASE, XP.VRTOTALPROMO,
			       PR.DSOBSNUTR, PW.DSDESCRICAO
			  FROM PRODUTO PR, ITEMPREBASE IB, PRODPEDWEB PW,
			       (
			        SELECT I.CDPRECOBASE,
			               I.CDPRODUTO,
			               B.VRTOTALPROMO,
                     I.NRORG
			          FROM ITEMPREBASE I, PROMOPRBASE B
			         WHERE (I.CDPRECOBASE  = :P_CDPRECOBASE)
			           AND (B.CDPRECOBASE  = I.CDPRECOBASE )
			           AND (B.CDPRODUTO    = I.CDPRODUTO   )
			           AND (B.DTINIVALIPB  = I.DTINIVALIPB )
                	   AND (B.NRORG        = I.NRORG       )
			           AND ((B.IDDIASPROMO = (TO_CHAR(SYSDATE,'D')))OR(B.IDDIASPROMO ='8'))
			           AND (TO_CHAR(SYSDATE,'DD/MM/YYYY') BETWEEN B.DTINIPROMO AND B.DTFINPROMO)
			       ) XP
			 WHERE (PR.IDPRODATIVPR    = 'S'               )
			   AND (PW.NRORG           = :P_NRORG          )
			   AND (PW.NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (IB.CDPRECOBASE     = :P_CDPRECOBASE    )
			   AND (IB.CDPRODUTO       = PR.CDPRODUTO      )
        	   AND (IB.NRORG           = PR.NRORG          )
        	   AND (PR.NRORG           = PW.NRORG          )
			   AND (PR.CDPRODUTO       = PW.CDPRODUTO      )
        	   AND (IB.NRORG           = XP.NRORG       (+))
			   AND (IB.CDPRODUTO       = XP.CDPRODUTO   (+))
			   AND (IB.CDPRECOBASE     = XP.CDPRECOBASE (+))
			   AND ((PR.CDPRODUTO      = :P_CDPRODUTO) OR (:P_CDPRODUTO = 'ALL'))
			 ORDER BY PR.CDARVPROD
SQL;
		
		try {
			$produtos = $this->getConnection($row)->fetchAll($query, array(':P_NRORG'           => $row['NRORG'],
																  ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																  ':P_CDPRECOBASE' 	 => $row['CDPRECOBASE'],
																  ':P_CDPRODUTO' 		 => $row['CDPRODUTO']));
		$queryFoto = <<<SQL1
			SELECT CDPRODUTO, NRSEQPROD, DSLINKFOTO, IDFOTOPRINC
			  FROM FOTOPRODWEB
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDPRODUTO       = :P_CDPRODUTO      )
			 ORDER BY IDFOTOPRINC DESC, NRSEQPROD
SQL1;
			foreach ($produtos as &$prod) {
			    $prod['FOTO'] = $this->getConnection($row)->fetchAll($queryFoto, array(':P_NRORG'           => $prod['NRORG'],
			    															  ':P_NRSEQWEBSERVICE' => $prod['NRSEQWEBSERVICE'],
			    															  ':P_CDPRODUTO'       => $prod['CDPRODUTO']));
			}
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("produtos", $produtos));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
/*******************************************************************************
	consumirProduto é a requisição da pilha de produtos.  A pilha é composta por
	produtos ativos, que não possuem código externo  e que possuem preço vigente
	na tabela de preço utilizada pelo webservice.
	
	Recebe como  parâmetros  o número  da organização, o número do webservice, o
	código da tabela de preço utilizada e o código do produto (ALL).
	
	Retorna um array com o  número da organização,  o número  do  webservice,  o
	código,  o código de árvore, o nome, a unidade, o preço, o preço promocional
	(se houver), o resumo e a descrição do produto.
	
	Para cada produto retorna um array com as fotos do produto contendo o código
	do produto, o  número sequencial da  foto, o link da foto e um identificador
	caso a foto seja a foto principal ou não.
*******************************************************************************/
    
    public function consumirProduto($response, $row) {
		$query = <<<SQL
			SELECT PW.NRORG, PW.NRSEQWEBSERVICE, PR.CDPRODUTO, PR.CDARVPROD,
			       PR.NMPRODUTO, PR.SGUNIDADE, IB.VRITEPREBASE, XP.VRTOTALPROMO,
			       PR.DSOBSNUTR, PW.DSDESCRICAO
			  FROM PRODUTO PR, ITEMPREBASE IB, PRODPEDWEB PW,
			       (
			        SELECT I.CDPRECOBASE,
			               I.CDPRODUTO,
			               B.VRTOTALPROMO
			          FROM ITEMPREBASE I, PROMOPRBASE B
			         WHERE (I.CDPRECOBASE  = :P_CDPRECOBASE)
			           AND (B.CDPRECOBASE  = I.CDPRECOBASE )
			           AND (B.CDPRODUTO    = I.CDPRODUTO   )
			           AND (B.DTINIVALIPB  = I.DTINIVALIPB )
			           AND ((B.IDDIASPROMO = (TO_CHAR(SYSDATE,'D')))OR(B.IDDIASPROMO ='8'))
			           AND (TO_CHAR(SYSDATE,'DD/MM/YYYY') BETWEEN B.DTINIPROMO AND B.DTFINPROMO)
			       ) XP
			 WHERE (ROWNUM < 200                           )
			   AND (PW.CDPRODEXTERNO IS NULL               )
			   AND (PR.IDPRODATIVPR    = 'S'               )
			   AND (PW.NRORG           = :P_NRORG          )
			   AND (PW.NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (IB.CDPRECOBASE     = :P_CDPRECOBASE    )
			   AND (IB.CDPRODUTO       = PR.CDPRODUTO      )
			   AND (PR.CDPRODUTO       = PW.CDPRODUTO      )
			   AND (IB.CDPRODUTO       = XP.CDPRODUTO   (+))
			   AND (IB.CDPRECOBASE     = XP.CDPRECOBASE (+))
			   AND ((PR.CDPRODUTO      = :P_CDPRODUTO) OR (:P_CDPRODUTO = 'ALL'))
			 ORDER BY PR.CDARVPROD
SQL;
		try {
			if(count($row) == 1){
				$row = $row[0];
			}
			$produtos = $this->getConnection($row)->fetchAll($query, array(':P_NRORG' 			 => $row['NRORG'],
															':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
															':P_CDPRECOBASE' 	 => $row['CDPRECOBASE'],
															':P_CDPRODUTO' 		 => $row['CDPRODUTO']));
		$queryFoto = <<<SQL1
			SELECT CDPRODUTO, NRSEQPROD, DSLINKFOTO, IDFOTOPRINC
			  FROM FOTOPRODWEB
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDPRODUTO       = :P_CDPRODUTO      )
			 ORDER BY IDFOTOPRINC DESC, NRSEQPROD
SQL1;
			foreach ($produtos as &$prod) {
			    $prod['FOTO'] = $this->getConnection($row)->fetchAll($queryFoto, array(':P_NRORG'           => $prod['NRORG'],
			    														':P_NRSEQWEBSERVICE' => $prod['NRSEQWEBSERVICE'],
			    														':P_CDPRODUTO'       => $prod['CDPRODUTO']));
			}
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("produtos", $produtos));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
/*******************************************************************************
	registraCodExterno é a  requisição  responsável  por gravar o código externo
	na tabela de produto depois do serviço de consumirProduto.
	"Ela esvazia a pilha de produtos"
	
	Recebe como parâmetros  o código do produto, o código externo do produto e o 
	número da organização.
	
	Identifica o produto como atualizado e grava a data da atualização.
*******************************************************************************/
    
    public function registraCodExterno($response, $dataSet) {
    	
    	$rows = $dataSet->getRows();
    	
		$query = <<<SQL
			UPDATE PRODPEDWEB
			   SET CDPRODEXTERNO    = :P_CDWEBEXTERNO
			 WHERE (CDPRODUTO       = :P_CDPRODUTO)
			   AND (NRORG           = :P_NRORG    )
SQL;
			foreach ($rows as $row) {
				try {
					$produtos = $this->getConnection($row)->executeUpdate($query, array(':P_CDWEBEXTERNO' => $row['CDWEBEXTERNO'],
																	':P_CDPRODUTO'    => $row['CDPRODUTO'],
																	':P_NRORG'        => $row['NRORG']));
			} catch (\Exception $e) {
					$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
		$queryProdWeb = <<<SQL1
			UPDATE PRODWEBSYNC
			   SET IDATUALIZADO     = 'S',
			       DTULTATUPROD     = SYSDATE
			 WHERE (CDPRODUTO       = :P_CDPRODUTO      )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (NRORG           = :P_NRORG          )
SQL1;
			foreach ($dataSet as $row) {
				try {
					$prodWeb = $this->getConnection($row)->fetchAll($queryProdWeb, array(':P_CDPRODUTO'       => $row['CDPRODUTO'],
					                                                      ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																		  ':P_NRORG'           => $row['NRORG']));
			} catch (\Exception $e) {
					$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
    }
    
/*******************************************************************************
	consultaProduto é a  requisição responsável por buscar todos os produtos que 
	precisam ser atualizados.
	
	Recebe como parêmtros o  número da organização,  o número  do  webservice, o
	código da tabela de preço e o código extero do produto (ALL).
	
	Retorna  um  array com  o  número  da organização, o número do webservice, o
	código, o  código de árvore, o nome, a unidade, o preço, o preço promocional
	(se houver),  o resumo,  a  descrição,  código  externo  a  data  da  última
	atualização e a data da última alteração.
	
	Para cada produto retorna um array com as fotos do produto contendo o código
	do produto,  o  número sequencial da foto, o link da foto e um identificador
	caso a foto seja a foto principal ou não.
*******************************************************************************/
    
    public function consultaProduto($response, $row) {
		$query = <<<SQL
			SELECT PW.NRORG, PW.NRSEQWEBSERVICE, PR.CDPRODUTO, PR.CDARVPROD,
			       PR.NMPRODUTO, PR.SGUNIDADE, IB.VRITEPREBASE, XP.VRTOTALPROMO,
			       PR.DSOBSNUTR, PW.DSDESCRICAO, 
			       PW.CDPRODEXTERNO, PS.DTULTATUPROD, PS.DTULTALTPROD
			  FROM PRODUTO PR, ITEMPREBASE IB, PRODPEDWEB PW, PRODWEBSYNC PS,
			       (
			        SELECT I.CDPRECOBASE,
			               I.CDPRODUTO,
			               B.VRTOTALPROMO
			          FROM ITEMPREBASE I, PROMOPRBASE B
			         WHERE (I.CDPRECOBASE  = :P_CDPRECOBASE)
			           AND (B.CDPRECOBASE  = I.CDPRECOBASE )
			           AND (B.CDPRODUTO    = I.CDPRODUTO   )
			           AND (B.DTINIVALIPB  = I.DTINIVALIPB )
			           AND ((B.IDDIASPROMO = (TO_CHAR(SYSDATE,'D')))OR(B.IDDIASPROMO ='8'))
			           AND (TO_CHAR(SYSDATE,'DD/MM/YYYY') BETWEEN B.DTINIPROMO AND B.DTFINPROMO)
			       ) XP
			 WHERE (ROWNUM < 200                           )
			   AND (PW.CDPRODEXTERNO IS NOT NULL           )
			   AND (PR.IDPRODATIVPR    = 'S'               )
			   AND (PS.IDATUALIZADO    = 'N'               )
			   AND (PW.NRORG           = :P_NRORG          )
			   AND (PW.NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (IB.CDPRECOBASE     = :P_CDPRECOBASE    )
			   AND (IB.CDPRODUTO       = PR.CDPRODUTO      )
			   AND (PR.CDPRODUTO       = PW.CDPRODUTO      )
			   AND (PS.CDPRODUTO       = PW.CDPRODUTO      )
			   AND (PS.NRSEQWEBSERVICE = PW.NRSEQWEBSERVICE)
			   AND (PS.NRORG           = PW.NRORG          )
			   AND (IB.CDPRODUTO       = XP.CDPRODUTO   (+))
			   AND (IB.CDPRECOBASE     = XP.CDPRECOBASE (+))
			   AND ((PW.CDPRODEXTERNO   = :P_CDWEBEXTERNO) OR (:P_CDWEBEXTERNO = 'ALL'))
			 ORDER BY PR.CDARVPROD
SQL;
		try {
			$produtos = $this->getConnection($row)->fetchAll($query, array(':P_NRORG'           => $row['NRORG'],
															':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
															':P_CDPRECOBASE'     => $row['CDPRECOBASE'],
															':P_CDWEBEXTERNO'    => $row['CDWEBEXTERNO']));
		$queryFoto = <<<SQL1
			SELECT CDPRODUTO, NRSEQPROD, DSLINKFOTO, IDFOTOPRINC
			  FROM FOTOPRODWEB
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDPRODUTO       = :P_CDPRODUTO      )
			 ORDER BY IDFOTOPRINC DESC, NRSEQPROD
SQL1;
			foreach ($produtos as &$prod) {
			    $prod['FOTO'] = $this->getConnection($row)->fetchAll($queryFoto, array(':P_NRORG'           => $prod['NRORG'],
			    														':P_NRSEQWEBSERVICE' => $prod['NRSEQWEBSERVICE'],
			    														':P_CDPRODUTO'       => $prod['CDPRODUTO']));
			}
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("produtos", $produtos));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
/*******************************************************************************
	produtoAtualizado  é a requisição responsável por identificar o produto como
	atualizado.
	
	Recebe como parêmtro  o código externo do produto e o número da organização.
*******************************************************************************/
    
    public function produtoAtualizado($response, $dataSet) {
		$query = <<<SQL
			UPDATE PRODWEBSYNC
			   SET IDATUALIZADO     = 'S',
			       DTULTATUPROD     = SYSDATE
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDPRODUTO       = :P_CDPRODUTO      )
SQL;
		foreach ($dataSet as $row) {
			try {
				$produtos = $this->getConnection($row)->fetchAll($query, array(':P_CDPRODUTO'       => $row['CDPRODUTO'],
																':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																':P_NRORG'           => $row['NRORG']));
			} catch (\Exception $e) {
				$response->setError(new  \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
    }
    
/*******************************************************************************
	atualizaProduto  é  a  requisição  responsável por atuaizar o produto com as 
	modificações feitas no site.
	
	Recebe como  parêmtro  o código  externo,  o nome,  o resumo, a descrição do
	produto, e o número da organização.
*******************************************************************************/
    
    public function atualizaProduto($response, $dataSet) {
		$queryProd = <<<SQL
			UPDATE PRODUTO
			   SET NMPRODUTO     = :P_NMPRODUTO,
			       DSOBSNUTR     = :P_DSOBSNUTR
			 WHERE (CDWEBEXTERNO = :P_CDWEBEXTERNO)
			   AND (NRORG        = :P_NRORG       )
SQL;
			foreach ($dataSet as $row) {
				try {
					$prod = $this->getConnection($row)->fetchAll($queryProd, array(':P_CDWEBEXTERNO' => $row['CDWEBEXTERNO'],
																	':P_DSOBSNUTR'    => $row['DSOBSNUTR'],
																	':P_NMPRODUTO'    => $row['NMPRODUTO'],
																	':P_NORG'         => $row['NRORG']));
			} catch (\Exception $e) {
					$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
		$queryProdWeb = <<<SQL1
			UPDATE PRODPEDWEB
			   SET DSDESCRICAO      = :P_DSDESCRICAO
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDPRODUTO       = (SELECT CDPRODUTO FROM PRODUTO WHERE CDWEBEXTERNO = :P_CDWEBEXTERNO))
SQL1;
			foreach ($dataSet as $row) {
				try {
					$prodWeb = $this->getConnection($row)->fetchAll($queryProd, array(':P_CDWEBEXTERNO'    => $row['CDWEBEXTERNO'],
																	   ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																	   ':P_DSDESCRICAO'     => $row['DSDESCRICAO'],
																	   ':P_NORG'            => $row['NRORG']));
			} catch (\Exception $e) {
					$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
    }
    
/*******************************************************************************
	consumirCliente  é a requisição da pilha de clientes. A pliha é composta por
	clientes ativos,  que não possuem  código externo  e que possuem endereço de 
	e-mail válido no endereço principal.
	
	Recebe  como  parêmtro  o número da organização e o código do cliente (ALL).
	
	Retorna um array com o número da organização, o código, o tipo de inscrição,
	a inscrição jurídica, a razão social,  o nome fantasia, o valor de limite de
	crédito, a vigencia do limite de crédito,  o identificador se o cliente esta
	ativo,  a data de nasceimento,  o sexo,  o RG,  o código  e nome do vendedor
	padrão (se houver),  o código  e  a  descrição  da  modalidade  de pagamento
	padrão (se houver),  o código  e  a  descrição  da  tabela  de  preço padrão
	principal (se houver).
	
	Para  cada  cliente  retorna um array com os endereços do cliente contendo o 
	código do cliente, o tipo do endereço,  o código e nome do país, a sigla e o
	nome do	estado,  o  código  e  nome  do  município, a descrição do endereço,
	o complemento, o cep,  o  número de telefone, o número do celular, o e-mail, 
	o código e nome do bairro.
*******************************************************************************/
    
    public function consumirCliente($response, $row) {
		$query = <<<SQL
			SELECT C.NRORG, C.CDCLIENTE, C.IDTPIJURCLIE, C.NRINSJURCLIE, 
			       C.NMRAZSOCCLIE, C.NMFANTCLIE, C.IDCLIEATIV,
			       LOWER(W.DSEMAILCLIE) AS DSEMAILCLIE, W.CDSENHACLIE,
			       DECODE(C.IDTPIJURCLIE, 'J', C.NRINSJURCLIE, '') AS CNPJ,
			       DECODE(C.IDTPIJURCLIE, 'F', C.NRINSJURCLIE, '') AS CPF,
			       C.CDVENDEDOR, V.NMRAZSOCVEN, C.CDMODPGTO, M.DSMODPGTO, B.CDPRECOBASE, B.DSPRECOBASE
			  FROM CLIENTE C, PRECOBASECLI P, PRECOBASE B, MODPGTO M, VENDEDOR V, CLIEPEDWEB W
			 WHERE (C.IDCLIEATIV       = 'S'              )
			   AND (P.IDPRBASEPRIN (+) = 'S'              )
			   AND (W.CDCLIEEXTERNO IS NULL               )
			   AND (W.NRSEQWEBSERVICE   = :P_NRSEQWEBSERVICE)
			   AND (ROWNUM             < 200              )
			   AND (C.NRORG            = :P_NRORG         )
			   AND (C.CDCLIENTE        = W.CDCLIENTE      )
			   AND (C.CDCLIENTE        = P.CDCLIENTE   (+))
			   AND (P.CDPRECOBASE      = B.CDPRECOBASE (+))
			   AND (C.CDMODPGTO        = M.CDMODPGTO   (+))
			   AND (C.CDVENDEDOR       = V.CDVENDEDOR  (+))
			   AND ((C.CDCLIENTE = :P_CDCLIENTE) OR (:P_CDCLIENTE = 'ALL'))
		       AND (C.CDCLIENTE IN (SELECT CDCLIENTE
		                              FROM CLIEPEDWEB E
		                             WHERE (E.DSEMAILCLIE IS NOT NULL   )
		                               AND (REGEXP_LIKE (DSEMAILCLIE,'^[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,4}$'))
		                            )
		           )
			 ORDER BY C.NMRAZSOCCLIE
SQL;
		try {
			$clientes = $this->getConnection($row)->fetchAll($query, array(':P_CDCLIENTE'       => $row['CDCLIENTE'],
															':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
			                                                ':P_NRORG'           => $row['NRORG']));
		$queryAddr = <<<SQL1
			SELECT E.CDCLIENTE, E.IDTPENDECLIE, E.CDPAIS, P.NMPAIS, E.SGESTADO,
			       LOWER(S.NMESTADO) AS NMESTADO,
			       E.CDMUNICIPIO, M.NMMUNICIPIO, E.DSENDECLIE, E.DSCOMPENDCLI,
			       REGEXP_REPLACE(E.NRCEPCLIE, '(-| |(|)|+)', '') AS NRCEPCLIE,
			       REGEXP_REPLACE(E.NRTELECLIE, '(-| |(|)|+)', '') AS NRTELECLIE,
			       REGEXP_REPLACE(E.NRTELECLIE1, '(-| |(|)|+)', '') AS NRTELECLIE1,
			       REGEXP_REPLACE(E.NRCELULARCLI, '(-| |(|)|+)', '') AS NRCELULARCLI,
			       LOWER(E.DSEMAILCLIE) AS DSEMAILCLIE, E.CDBAIRRO, B.NMBAIRRO
			  FROM ENDECLIE E, PAIS P, ESTADO S, MUNICIPIO M, BAIRRO B
			 WHERE (E.NRORG       = :P_NRORG        )
			   AND (E.CDPAIS      = P.CDPAIS     (+))
			   AND (E.CDPAIS      = S.CDPAIS     (+))
			   AND (E.SGESTADO    = S.SGESTADO   (+))
			   AND (E.CDPAIS      = M.CDPAIS     (+))
			   AND (E.SGESTADO    = M.SGESTADO   (+))
			   AND (E.CDMUNICIPIO = M.CDMUNICIPIO(+))
			   AND (E.CDPAIS      = B.CDPAIS     (+))
			   AND (E.SGESTADO    = B.SGESTADO   (+))
			   AND (E.CDMUNICIPIO = B.CDMUNICIPIO(+))
			   AND (E.CDBAIRRO    = B.CDBAIRRO   (+))
			   AND ((E.CDCLIENTE = :P_CDCLIENTE) OR (:P_CDCLIENTE = 'ALL'))
			 ORDER BY P.NMPAIS, S.NMESTADO, M.NMMUNICIPIO, B.NMBAIRRO
SQL1;
			foreach ($clientes as &$client) {
				$client['ADDRESSES'] = $this->getConnection($row)->fetchAll($queryAddr, array(':P_CDCLIENTE' => $client['CDCLIENTE'],
																			   ':P_NRORG'     => $client['NRORG']));
			}
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("clientes", $clientes));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
/*******************************************************************************
	registraClienteExterno  é  a  requisição  responsável  por  gravar  o código
	externo  na  tabela  de  cliente  depois do serviço de consumirCliente. "Ela
	esvazia a pilha de clientes".
	
	Recebe  como  parêmtros o código do cliente o código externo do cliente, e o 
	número da organização.
	
	Identifica o cliente como atualizado e grava a data da atualização.
*******************************************************************************/
    
    public function registraClienteExterno($response, $dataSet) {
    	
    	$dataSet = $dataSet->getRows();
    	
    	
		$query = <<<SQL
			UPDATE CLIEPEDWEB
			   SET CDCLIEEXTERNO    = :P_CDCLIEEXTERNO
			 WHERE (CDCLIENTE       = :P_CDCLIENTE)
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (NRORG           = :P_NRORG    )
SQL;
		foreach ($dataSet as $row) {
			try {
				$clientes = $this->getConnection($row)->executeUpdate($query, array(':P_CDCLIEEXTERNO'    => $row['CDCLIEEXTERNO'],
																					':P_CDCLIENTE'        => $row['CDCLIENTE'],
																					':P_NRSEQWEBSERVICE'  => $row['NRSEQWEBSERVICE'],
																					':P_NRORG'            => $row['NRORG']));
																
			} catch (\Exception $e) {
				$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}

		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));

		$queryClieWeb = <<<SQL1
			UPDATE CLIEWEBSYNC
			   SET IDATUALIZADO     = 'S',
			       DTULTATUCLIE     = SYSDATE
			 WHERE (CDCLIENTE       = :P_CDCLIENTE      )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (NRORG           = :P_NRORG          )
SQL1;
			foreach ($dataSet as $row) {
				try {
					$clieWeb = $this->getConnection($row)->executeUpdate($queryClieWeb, array(':P_CDCLIENTE'       => $row['CDCLIENTE'],
										                                                      ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																							  ':P_NRORG'           => $row['NRORG']));
																							  
			} catch (\Exception $e) {
					$response->setError(new  \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
    }
    
/*******************************************************************************
	consultaCliente  é  a  requisição responsável por buscar os clientes que não
	estão atualizados.
	
	Recebe como parêmtro o  número  da organização e o código externo do cliente 
	(ALL).
	
	Retorna um array com o número da organização, o código, o tipo de inscrição,
	a inscrição jurídica, a razão social,  o nome fantasia, o valor de limite de
	crédito,  a vigencia do limite de crédito, o identificador se o cliente esta
	ativo,   a data de nasceimento,  o sexo,  o RG,  o código e nome do vendedor
	padrão (se houver),  o código  e  a  descrição  da  modalidade  de pagamento
	padrão (se houver),  o código  e  a  descrição  da  tabela  de  preço padrão
	principal (se houver), o  código  externo  do  cliente,  a  data  da  última
	atualização e a data da última alteração.
	
	Para cada  cliente  retorna  um array com os endereços do cliente contendo o 
	código do cliente, o tipo do endereço,  o código e nome do país, a sigla e o 
	nome do	estado,  o código e  nome do  município, a  descrição  do  endereço,
	o complemento, o cep, o número de telefone, o número do celular,  o  e-mail,
	o código e nome do bairro.

*******************************************************************************/
    
    public function consultaCliente($response, $row) {
		$query = <<<SQL
			SELECT C.NRORG, C.CDCLIENTE, C.IDTPIJURCLIE, C.NRINSJURCLIE,
			       C.NMRAZSOCCLIE, C.NMFANTCLIE, C.IDCLIEATIV,
			       LOWER(W.DSEMAILCLIE) AS DSEMAILCLIE, W.CDSENHACLIE,
			       DECODE(C.IDTPIJURCLIE, 'J', C.NRINSJURCLIE, '') AS CNPJ,
			       DECODE(C.IDTPIJURCLIE, 'F', C.NRINSJURCLIE, '') AS CPF,
			       C.CDVENDEDOR, V.NMRAZSOCVEN, C.CDMODPGTO, M.DSMODPGTO, B.CDPRECOBASE, B.DSPRECOBASE,
			       W.CDCLIEEXTERNO, S.DTULTATUCLIE, S.DTULTALTCLIE
			  FROM CLIENTE C, PRECOBASECLI P, PRECOBASE B, MODPGTO M, VENDEDOR V, CLIEWEBSYNC S, CLIEPEDWEB W
			 WHERE (C.IDCLIEATIV       = 'S'               )
			   AND (S.IDATUALIZADO     = 'N'               )
			   AND (P.IDPRBASEPRIN (+) = 'S'               )
			   AND (W.CDCLIEEXTERNO IS NOT NULL            )
			   AND (ROWNUM             < 400               )
			   AND (S.NRORG            = :P_NRORG          )
			   AND (S.NRSEQWEBSERVICE  = :P_NRSEQWEBSERVICE)
			   AND (S.CDCLIENTE        = C.CDCLIENTE       )
			   AND (S.NRORG            = C.NRORG           )
			   AND (S.NRSEQWEBSERVICE  = W.NRSEQWEBSERVICE )
			   AND (S.CDCLIENTE        = W.CDCLIENTE       )
			   AND (S.NRORG            = W.NRORG           )
			   AND (C.CDCLIENTE        = P.CDCLIENTE    (+))
			   AND (P.CDPRECOBASE      = B.CDPRECOBASE  (+))
			   AND (C.CDMODPGTO        = M.CDMODPGTO    (+))
			   AND (C.CDVENDEDOR       = V.CDVENDEDOR   (+))
			   AND ((W.CDCLIEEXTERNO = :P_CDWEBEXTERNO) OR (:P_CDWEBEXTERNO = 'ALL'))
			   AND (C.CDCLIENTE IN (SELECT CDCLIENTE
			                          FROM ENDECLIE E
			                         WHERE (E.IDTPENDECLIE = 'P'        )
			                           AND (C.CDCLIENTE    = E.CDCLIENTE)
			                       )
			       )
			 ORDER BY C.NMRAZSOCCLIE
SQL;
		try {
			$clientes = $this->getConnection($row)->fetchAll($query, array(':P_CDWEBEXTERNO'    => $row['CDWEBEXTERNO'],
															':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
															':P_NRORG'            => $row['NRORG']));
		$queryAddr = <<<SQL1
			SELECT E.CDCLIENTE, E.IDTPENDECLIE, E.CDPAIS, P.NMPAIS, E.SGESTADO,
			       LOWER(S.NMESTADO) AS NMESTADO,
			       E.CDMUNICIPIO, M.NMMUNICIPIO, E.DSENDECLIE, E.DSCOMPENDCLI,
			       REGEXP_REPLACE(E.NRCEPCLIE, '(-| |(|)|+)', '') AS CEP,
			       REGEXP_REPLACE(E.NRTELECLIE, '(-| |(|)|+)', '') AS NRTELECLIE,
			       REGEXP_REPLACE(E.NRTELECLIE1, '(-| |(|)|+)', '') AS NRTELECLIE1,
			       REGEXP_REPLACE(E.NRCELULARCLI, '(-| |(|)|+)', '') AS NRCELULARCLI,
			       LOWER(E.DSEMAILCLIE) AS DSEMAILCLIE, E.CDBAIRRO, B.NMBAIRRO,
			       E.NRTELRESICLI, E.NRENDERECOPARC
			  FROM ENDECLIE E, PAIS P, ESTADO S, MUNICIPIO M, BAIRRO B
			 WHERE (E.NRORG       = :P_NRORG        )
			   AND (E.CDPAIS      = P.CDPAIS     (+))
			   AND (E.CDPAIS      = S.CDPAIS     (+))
			   AND (E.SGESTADO    = S.SGESTADO   (+))
			   AND (E.CDPAIS      = M.CDPAIS     (+))
			   AND (E.SGESTADO    = M.SGESTADO   (+))
			   AND (E.CDMUNICIPIO = M.CDMUNICIPIO(+))
			   AND (E.CDPAIS      = B.CDPAIS     (+))
			   AND (E.SGESTADO    = B.SGESTADO   (+))
			   AND (E.CDMUNICIPIO = B.CDMUNICIPIO(+))
			   AND (E.CDBAIRRO    = B.CDBAIRRO   (+))
			   AND ((E.CDCLIENTE = :P_CDCLIENTE) OR (:P_CDCLIENTE = 'ALL'))
			 ORDER BY P.NMPAIS, S.NMESTADO, M.NMMUNICIPIO, B.NMBAIRRO
SQL1;
			foreach ($clientes as &$client) {
				$client['ADDRESSES'] = $this->getConnection($row)->fetchAll($queryAddr, array(':P_CDCLIENTE' => $client['CDCLIENTE'],
																			   ':P_NRORG'     => $client['NRORG']));
			}
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("clientes", $clientes));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
/*******************************************************************************
	clienteAtualizado  é a requisição responsável por identificar o cliente como
	atualizado.
	
	Recebe  como parêmtro o código externo do produto e o número da organização.
*******************************************************************************/
    
    public function clienteAtualizado($response, $dataSet) {
		$query = <<<SQL
			UPDATE CLIEWEBSYNC
			   SET IDATUALIZADO     = 'S',
			       DTULTATUCLIE     = SYSDATE
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDCLIENTE       = :P_CDCLIENTE      )
SQL;
			foreach ($dataSet as $row) {
				try {
					$clientes = $this->getConnection($row)->fetchAll($query, array(':P_CDWEBEXTERNO'    => $row['CDWEBEXTERNO'],
																	':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																	':P_NORG'            => $row['NRORG']));
			} catch (\Exception $e) {
					$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("status", array('Ok')));
    }
    
/*******************************************************************************
	validaPedido é a função que valida o código externo do pedido.
*******************************************************************************/
    
    private function validaPedido(&$row, $connection){
		$result =  array( "valido" => true);	
		
		$queryPed = <<<SQL
			SELECT NRPEDIDO
			  FROM PEDWEBEXT
			 WHERE (CDPEDEXTERNO    = :P_CDPEDEXTERNO)
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
		      AND (NRORG           = :P_NRORG       )
		      
SQL;
		if($row['PEDEXTERNO'] == null){
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Codigo externo do pedido nao enviado.|'));
		
		}else{
			$ped = $this->getConnection($connection)->fetchAll($queryPed, array(':P_CDPEDEXTERNO'    => $row['PEDEXTERNO'],
															    ':P_NRSEQWEBSERVICE' => $connection['NRSEQWEBSERVICE'],
															    ':P_NRORG'           => $connection['NRORG']));
		
			if(!empty($ped)){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Pedido ja cadastrado.|'));
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaFilial é a função que valida a filial.
*******************************************************************************/
	
	private function validaFilial($row, $connection){
		$result =  array( "valido" => true);	
		
		$queryFili = <<<SQL
			SELECT CDFILIAL
			  FROM FILIAL
			 WHERE (CDFILIAL = :P_CDFILIAL)
		       AND (NRORG    = :P_NRORG   )
SQL;
		if($row['CDFILIAL'] == null){
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Filial nao enviada no pedido.|'));
		}else{
			$filial = $this->getConnection($connection)->fetchAll($queryFili, array(':P_CDFILIAL' => $row['CDFILIAL'],
																	':P_NRORG'    => $row['NRORG']));
			if(empty($filial)){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Filial '.$row['CDFILIAL'].' nao encontrada.|'));
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaPrecoBase é a função que valida a tabela de preço.
*******************************************************************************/
	
	private function validaPrecoBase($row, $connection){
		$result =  array( "valido" => true);
		//Identifica que o preço dos produtos virá do site ou do ERP.
		if ($row['PRECOSITE'] == 'N') {
			$queryPrBaseClie = <<<SQL0
				SELECT NRORG, CDCLIENTE, CDPRECOBASE, IDPRBASEPRIN
				  FROM PRECOBASECLI
				 WHERE (NRORG     = :P_NRORG    )
				   AND (CDCLIENTE = :P_CDCLIENTE)
				 ORDER BY IDPRBASEPRIN DESC, CDPRECOBASE
SQL0;
			$precoBaseClie = $this->getConnection($connection)->fetchAll($queryPrBaseClie, array(':P_CDCLIENTE' => $row['CDCLIEEXTERNO'],
																				 ':P_NRORG'     => $row['NRORG']));
			if(empty($precoBaseClie)){
				if ($row['CDPRECOBASE'] == null) {
					$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Tabela de preco base nao enviada no pedido.|'));
				} else {
					$queryPrBase = <<<SQL1
						SELECT CDPRECOBASE
						  FROM PRECOBASE
						 WHERE (CDPRECOBASE = :P_CDPRECOBASE)
						   AND (NRORG       = :P_NRORG      )
SQL1;
					$preco = $this->getConnection($connection)->fetchAll($queryPrBase, array(':P_CDPRECOBASE' => $row['CDPRECOBASE'],
																			 ':P_NRORG'       => $row['NRORG']));
					if(empty($preco)){
						$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Tabela de preco base '.$row['CDPRECOBASE'].' nao encontrada.|'));
					}
				}
			} else {
				$row['CDPRECOBASE'] = $precoBaseClie[0]['CDPRECOBASE'];
			}

		} else {
			if ($row['CDPRECOBASE'] == null) {
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Tabela de preco base nao enviada no pedido.|'));
			} else {
				$queryPrBase = <<<SQL2
					SELECT CDPRECOBASE
					  FROM PRECOBASE
					 WHERE (CDPRECOBASE = :P_CDPRECOBASE)
					   AND (NRORG       = :P_NRORG      )
SQL2;
				$preco = $this->getConnection($connection)->fetchAll($queryPrBase, array(':P_CDPRECOBASE' => $row['CDPRECOBASE'],
																		 ':P_NRORG'       => $row['NRORG']));
				if (empty($preco)) {
					$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Tabela de preco base '.$row['CDPRECOBASE'].' nao encontrada.|'));
				}
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaModPgto é a função que valida a modalidade de pagamento.
*******************************************************************************/
	
	private function validaModPgto(&$row, $connection){
		$result =  array( "valido" => true);
		$queryModPgto = <<<SQL
			SELECT CDMODPGTO
			  FROM MODPEDWEB
			 WHERE (CDMODEXTERNO    = :P_CDMODPGTO      )
			   AND (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
SQL;
		$queryConfig = <<<SQL1
			SELECT CDMODPGTO
			  FROM PEDIDOWEB
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
SQL1;
		$config = $this->getConnection($connection)->fetchAll($queryConfig, array(':P_NRORG'           => $row['NRORG'],
																  ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE']));

		if($row['CDMODPGTO'] == null){
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Modalidade de pagamento nao enviada no pedido.|'));
		}else{
			$mod = $this->getConnection($connection)->fetchAll($queryModPgto, array(':P_CDMODPGTO'       => $row['CDMODPGTO'],
																	':P_NRORG'           => $row['NRORG'],
																	':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE']));
			if(empty($mod)){
				if(empty($config)){
					$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Modalidade de pagamento '.$row['CDMODPGTO'].' nao encontrada.|'));
				}else{
					$row['CDMODPGTO'] = $config[0]['CDMODPGTO'];
				}
			}else{
				$row['CDMODPGTO'] = $mod[0]['CDMODPGTO'];
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaOperador é a função que valida o operador.
*******************************************************************************/
	
	private function validaOperador($row, $connection){
		$result =  array( "valido" => true);	
		$queryOper = <<<SQL
			SELECT CDOPERADOR
			  FROM OPERADOR
			 WHERE (CDOPERADOR = :P_CDOPERADOR)
		       AND (NRORG      = :P_NRORG     )
SQL;
		if($row['CDOPERADOR'] == null){
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Operador nao enviado no pedido.|'));
		}else{
			$oper = $this->getConnection($connection)->fetchAll($queryOper, array(':P_CDOPERADOR' => $row['CDOPERADOR'],
																  ':P_NRORG'      => $row['NRORG']));
			if(empty($oper)){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Operador '.$row['CDOPERADOR'].' nao encontrado.|'));
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaTipoOper é a função que valida o tipo de operação.
*******************************************************************************/

	
	private function validaTipoOper($row, $connection){
		$result =  array( "valido" => true);	

		$queryObrigTpOper = <<<SQL
					SELECT IDOBRTPOPPED 
					FROM PARAMPEDIDO
					WHERE CDFILIAL = :P_CDFILIAL
SQL;
		

		$queryTpOper = <<<SQL2
			SELECT CDTIPOOPER
			  FROM TIPOOPERAC
			 WHERE (IDENTRSAIDOP = :P_IDTIPOOPERWEB)
			   AND (CDTIPOOPER   = :P_CDTIPOOPERWEB)
			   AND (NRORG        = :P_NRORG        )
SQL2;

		$obrigTpOper = $this->getConnection($connection)->fetchAll($queryObrigTpOper, array(':P_CDFILIAL' => $row['CDFILIAL']));
		
		if(isset($obrigTpOper)){
			$obrigTpOper = $obrigTpOper[0]['IDOBRTPOPPED'];
		}else {
			$obrigTpOper = '';
		}

		if($obrigTpOper == 'S'){
			
			if($row['CDTIPOOPERWEB'] == null){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Tipo de operacao nao enviada no pedido.|'));
			}else{
				$tpOper = $this->getConnection($connection)->fetchAll($queryTpOper, array(':P_IDTIPOOPERWEB' => $row['IDTIPOOPERWEB'],
																		  ':P_CDTIPOOPERWEB' => $row['CDTIPOOPERWEB'],
																		  ':P_NRORG'         => $row['NRORG']));
				if(empty($tpOper)){
					$result = array("valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Tipo de Operacao '.$row['CDTIPOOPERWEB'].' nao encontrado.|'));
				}
			}
		}else{
			$row['CDTIPOOPERWEB'] = '';
		}
		
		return $result;
	}
	
/*******************************************************************************
	validaCliente é  a  função  que  valida  o cliente e o cadastra caso não for 
	encontrado.
*******************************************************************************/
	
	private function validaCliente(&$row, $request, $response, $rows, $connection){
		$result =  array( "valido" => true);
		if($row['CDCLIEEXTERNO'] == null){
			// Código externo do cliente não enviado.
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente nao enviado no pedido.|'));
		} else {
			$queryClieExt = <<<SQL
				SELECT CDCLIENTE
				  FROM CLIEPEDWEB
				 WHERE (CDCLIEEXTERNO   = :P_CDCLIEEXTERNO  )
				   AND (NRORG           = :P_NRORG          )
SQL;
			$clienteExt = $this->getConnection($connection)->fetchAll($queryClieExt, array(':P_CDCLIEEXTERNO' => $row['CDCLIEEXTERNO'],
																		   ':P_NRORG'         => $row['NRORG']));
			// Cliente não encontrado com esse código externo.
			if(empty($clienteExt)){
				$queryClie = <<<SQL1
					SELECT CDCLIENTE
					  FROM CLIEPEDWEB
					 WHERE (CDCLIENTE   = :P_CDCLIEEXTERNO  )
					   AND (NRORG       = :P_NRORG          )
SQL1;
				$cliente = $this->getConnection($connection)->fetchAll($queryClie, array(':P_CDCLIEEXTERNO' => $row['CDCLIEEXTERNO'],
																		 ':P_NRORG'         => $row['NRORG']));
				// Cliente não encontrado com esse código interno.
				if(empty($cliente)){
					try {
						$queryCodClie = <<<SQL2
							SELECT C.CDCLIENTE, C.NMRAZSOCCLIE, W.CDCLIEEXTERNO
							  FROM CLIENTE C, CLIEPEDWEB W
							 WHERE (C.CDCLIENTE = W.CDCLIENTE (+))
							   AND (C.NRORG     = W.NRORG     (+))
							   AND (C.CDCLIENTE = :P_CDCLIENTE   )
							   AND (C.NRORG     = :P_NRORG       )
SQL2;
						$codClie = $this->getConnection($connection)->fetchAll($queryCodClie, array(':P_CDCLIENTE' => $row['CDCLIENTE'],
																					':P_NRORG'     => $row['NRORG']));
						// Cliente não encontrado com (cpf/cnpj) enviado. Cliente será cadastrado.
						if(empty($codClie)){

							$row['CEP'] = $row['NRCEPCLIE'];
							
							$endereco = $this->findAddress($row, $connection);
							
							if(is_array($endereco)){
								
								if(!empty($endereco)){
									$queryInsereCliente = <<<SQL3
									INSERT INTO CLIENTE (NRORG,           CDCLIENTE,       IDTPIJURCLIE,    NRINSJURCLIE,    NMRAZSOCCLIE,    NMFANTCLIE,
									                     IDENDEMISCLI,    IDENDCFOPCLI,    CDVENDEDOR,      IDCLIEATIV,      IDZERSALDCON,    IDGERNFCLIE,
									                     IDSITFINCLIE,    IDLIGEXTCLIE,    CDMODPGTO,       NRLIMATEMES,     IDTPLIMATEFAT,   IDLIBATDCLIINAD,
									                     IDCADVERSAOCLI,  IDTIPOPORTECLIE, IDPGFRETTRANCLI, IDCOMPARQXMLCLI, IDCLISECATCLPRI, IDGRAVOBSCLIPED,
									                     IDEXBTPNOMECLIE, IDUTDESCICMS,    IDUTLALVCLIE,    IDCONSFINAL,     IDCLIPRINCIPAL,  NRINSJURTRAN, IDTPIJURTRAN, CDTIPTRANS)
									             VALUES (:P_NRORG,        UPPER(:P_CDCLIENTE),    :P_IDTPIJURCLIE, :P_NRINSJURCLIE, UPPER(:P_NMRAZSOCCLIE), UPPER(:P_NMFANTCLIE),
									                     'P',             'P',             :P_CDVENDEDOR,   'S',             'S',             '1',
									                     'N',             'N',             :P_CDMODPGTO,    '10',            'P',             'N',
									                     'N',             'P',             '9',             'S',             'N',             'S',
									                     'F',             'N',             'N',             'S',             'N',			  :P_NRINSJURTRAN, :P_IDTPIJURTRAN, :P_CDTIPTRANS)
SQL3;
								
									$clienteInserido = $this->getConnection($connection)->executeUpdate($queryInsereCliente, array(':P_NRORG'        => $row['NRORG'],
																											   ':P_CDCLIENTE'    => $row['CDCLIENTE'],
																											   ':P_IDTPIJURCLIE' => $row['IDTPIJURCLIE'],
																											   ':P_NRINSJURCLIE' => $row['NRINSJURCLIE'],
																											   ':P_NMRAZSOCCLIE' => $row['NMRAZSOCCLIE'],
																											   ':P_NMFANTCLIE'   => $row['NMFANTCLIE'],
																											   ':P_CDVENDEDOR'   => $row['CDVENDEDOR'],
																											   ':P_CDMODPGTO'    => $row['CDMODPGTO'],
																											   ':P_NRINSJURTRAN' => isset($row['NRINSJURTRAN']) ? $row['NRINSJURTRAN'] : '',
																											   ':P_IDTPIJURTRAN' => isset($row['IDTPIJURTRAN']) ? $row['IDTPIJURTRAN'] : '',
																											   ':P_CDTIPTRANS'	 => isset($row['CDTIPTRANS'])   ? $row['CDTIPTRANS']   : ''));
									$queryInsereAux = <<<SQL4
										INSERT INTO CLIEPEDWEB (NRORG,    NRSEQWEBSERVICE,    CDCLIENTE,    DSEMAILCLIE,    CDCLIEEXTERNO)
														VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, :P_DSEMAILCLIE, :P_CDCLIEEXTERNO)
SQL4;
									$auxInserido = $this->getConnection($connection)->executeUpdate($queryInsereAux, array(':P_NRORG'           => $row['NRORG'],
																									   ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																									   ':P_CDCLIENTE'       => $row['CDCLIENTE'],
																									   ':P_DSEMAILCLIE'     => $row['DSEMAILCLIE'],
																									   ':P_CDCLIEEXTERNO'   => $row['CDCLIEEXTERNO']));
								
									$queryInsereSync = <<<SQL5
										INSERT INTO CLIEWEBSYNC (NRORG,    NRSEQWEBSERVICE,    CDCLIENTE,    DTULTALTCLIE, IDATUALIZADO)
													 VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, SYSDATE,      'N')
SQL5;
									$SyncInserido = $this->getConnection($connection)->executeUpdate($queryInsereSync, array(':P_NRORG'           => $row['NRORG'],
																								 	     ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																								 	     ':P_CDCLIENTE'       => $row['CDCLIENTE']));
									$row['CDCLIEEXTERNO'] = $row['CDCLIENTE'];
									$tpEnd = ['P','T','C'];
									
									foreach($tpEnd as $tipoEndereco){
										$queryInsereEndereco = <<<SQL6
											INSERT INTO ENDECLIE (CDCLIENTE,      IDTPENDECLIE,   CDPAIS,          SGESTADO,
											                      CDMUNICIPIO,    DSENDECLIE,     DSCOMPENDCLI,    NRCEPCLIE,
											                      NRTELECLIE,     NRTELECLIE1,    DSEMAILCLIE,     DSPTOREFECLI,    CDBAIRRO,
											                      NRORG, NMBAIRCLIE)
											            VALUES   (:P_CDCLIENTE,   :P_IDTPENDECLIE, :P_CDPAIS,      :P_SGESTADO,
											                      :P_CDMUNICIPIO, UPPER(:P_DSENDECLIE),  :P_DSCOMPENDCLI, :P_NRCEPCLIE,
											                      :P_NRTELECLIE, :P_NRTELECLIE1,  :P_DSEMAILCLIE, UPPER(:P_DSPTOREFECLI), :P_CDBAIRRO,
											                      :P_NRORG, :P_NMBAIRCLIE)
SQL6;
		
										$enderecoInserido = $this->getConnection($connection)->executeUpdate($queryInsereEndereco, array(':P_NRORG'        => $row['NRORG'],
																													     ':P_CDCLIENTE'    => $row['CDCLIENTE'],   
																													     ':P_CDPAIS'       => $endereco['CDPAIS'],
																													     ':P_SGESTADO'     => $endereco['SGESTADO'],
																									                     ':P_CDMUNICIPIO'  => $endereco['CDMUNICIPIO'],
																									                     ':P_DSENDECLIE'   => $row['DSENDECLIE'],
																									                     ':P_DSCOMPENDCLI' => $row['DSCOMPENDCLI'],
																									                     ':P_NRCEPCLIE'    => $row['NRCEPCLIE'],
																									                     ':P_NRTELECLIE'   => $row['NRTELECLIE'],
																									                     ':P_NRTELECLIE1'   => $row['NRTELECLIE1'],
																									                     ':P_DSEMAILCLIE'  => $row['DSEMAILCLIE'],
																									                     ':P_DSPTOREFECLI' => $row['DSPTOREFECLI'],
																									                     ':P_CDBAIRRO'     => $endereco['CDBAIRRO'],
																									                     ':P_NMBAIRCLIE'   => $endereco['NMBAIRRO'],
																									                     ':P_IDTPENDECLIE' => $tipoEndereco));
									}
								}else{
									$queryMunicipio = <<<SQL12
									SELECT *
									  FROM MUNICIPIO 
									 WHERE (UPPER(REMOVE_ACENTOS(NMMUNICIPIO)) = UPPER(REMOVE_ACENTOS(:P_NMMUNICIPIO)))
SQL12;
									
									$municipio = $this->getConnection($connection)->fetchAll($queryMunicipio, array(':P_NMMUNICIPIO' => $row['NMMUNICIPIO']));
									
									if(!empty($municipio)){
										$queryInsereCliente = <<<SQL3
											INSERT INTO CLIENTE (NRORG,           CDCLIENTE,       IDTPIJURCLIE,    NRINSJURCLIE,    NMRAZSOCCLIE,    NMFANTCLIE,
											                     IDENDEMISCLI,    IDENDCFOPCLI,    CDVENDEDOR,      IDCLIEATIV,      IDZERSALDCON,    IDGERNFCLIE,
											                     IDSITFINCLIE,    IDLIGEXTCLIE,    CDMODPGTO,       NRLIMATEMES,     IDTPLIMATEFAT,   IDLIBATDCLIINAD,
											                     IDCADVERSAOCLI,  IDTIPOPORTECLIE, IDPGFRETTRANCLI, IDCOMPARQXMLCLI, IDCLISECATCLPRI, IDGRAVOBSCLIPED,
											                     IDEXBTPNOMECLIE, IDUTDESCICMS,    IDUTLALVCLIE,    IDCONSFINAL,     IDCLIPRINCIPAL)
											             VALUES (:P_NRORG,        UPPER(:P_CDCLIENTE),    :P_IDTPIJURCLIE, :P_NRINSJURCLIE, UPPER(:P_NMRAZSOCCLIE), UPPER(:P_NMFANTCLIE),
											                     'P',             'P',             :P_CDVENDEDOR,   'S',             'S',             '1',
											                     'N',             'N',             :P_CDMODPGTO,    '10',            'P',             'N',
											                     'N',             'P',             '9',             'S',             'N',             'S',
											                     'F',             'N',             'N',             'S',             'N')
SQL3;
										$clienteInserido = $this->getConnection($connection)->executeUpdate($queryInsereCliente, array(':P_NRORG'        => $row['NRORG'],
																													   ':P_CDCLIENTE'    => $row['CDCLIENTE'],
																													   ':P_IDTPIJURCLIE' => $row['IDTPIJURCLIE'],
																													   ':P_NRINSJURCLIE' => $row['NRINSJURCLIE'],
																													   ':P_NMRAZSOCCLIE' => $row['NMRAZSOCCLIE'],
																													   ':P_NMFANTCLIE'   => $row['NMFANTCLIE'],
																													   ':P_CDVENDEDOR'   => $row['CDVENDEDOR'],
																													   ':P_CDMODPGTO'    => $row['CDMODPGTO']));
										$queryInsereAux = <<<SQL4
											INSERT INTO CLIEPEDWEB (NRORG,    NRSEQWEBSERVICE,    CDCLIENTE,    DSEMAILCLIE,    CDCLIEEXTERNO)
															VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, :P_DSEMAILCLIE, :P_CDCLIEEXTERNO)
SQL4;
										$auxInserido = $this->getConnection($connection)->executeUpdate($queryInsereAux, array(':P_NRORG'           => $row['NRORG'],
																											   ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																											   ':P_CDCLIENTE'       => $row['CDCLIENTE'],
																											   ':P_DSEMAILCLIE'     => $row['DSEMAILCLIE'],
																											   ':P_CDCLIEEXTERNO'   => $row['CDCLIEEXTERNO']));
										
										$queryInsereSync = <<<SQL5
											INSERT INTO CLIEWEBSYNC (NRORG,    NRSEQWEBSERVICE,    CDCLIENTE,    DTULTALTCLIE, IDATUALIZADO)
															 VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, SYSDATE,      'N')
SQL5;
										$SyncInserido = $this->getConnection($connection)->executeUpdate($queryInsereSync, array(':P_NRORG'           => $row['NRORG'],
																										 	     ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																										 	     ':P_CDCLIENTE'       => $row['CDCLIENTE']));
										$row['CDCLIEEXTERNO'] = $row['CDCLIENTE'];
										$tpEnd = ['P','T','C'];
										
										foreach($tpEnd as $tipoEndereco){
											$queryInsereEndereco = <<<SQL6
												INSERT INTO ENDECLIE (CDCLIENTE,      IDTPENDECLIE,   CDPAIS,          SGESTADO,
												                      CDMUNICIPIO,    DSENDECLIE,     DSCOMPENDCLI,    
												                      NRTELECLIE,     NRTELECLIE1,    DSEMAILCLIE,     DSPTOREFECLI,   
												                      NRORG)
												            VALUES   (:P_CDCLIENTE,   :P_IDTPENDECLIE, :P_CDPAIS,      :P_SGESTADO,
												                      :P_CDMUNICIPIO, UPPER(:P_DSENDECLIE),  :P_DSCOMPENDCLI, 
												                      :P_NRTELECLIE, :P_NRTELECLIE1,  :P_DSEMAILCLIE, UPPER(:P_DSPTOREFECLI), 
												                      :P_NRORG)
SQL6;
											$enderecoInserido = $this->getConnection($connection)->executeUpdate($queryInsereEndereco, array(':P_NRORG'        => $row['NRORG'],
																														     ':P_CDCLIENTE'    => $row['CDCLIENTE'],   
																														     ':P_CDPAIS'       => $municipio[0]['CDPAIS'],
																														     ':P_SGESTADO'     => $municipio[0]['SGESTADO'],
																										                     ':P_CDMUNICIPIO'  => $municipio[0]['CDMUNICIPIO'],
																										                     ':P_NMBAIRCLIE'   => $row['NMBAIRCLIE'],
																										                     ':P_DSENDECLIE'   => $row['DSENDECLIE'],
																										                     ':P_DSCOMPENDCLI' => $row['DSCOMPENDCLI'],
																										                     ':P_NRTELECLIE'   => $row['NRTELECLIE'],
																										                     ':P_NRTELECLIE1'   => $row['NRTELECLIE1'],
																										                     ':P_DSEMAILCLIE'  => $row['DSEMAILCLIE'],
																										                     ':P_DSPTOREFECLI' => $row['DSPTOREFECLI'],
																										                     
																										                     ':P_IDTPENDECLIE' => $tipoEndereco));
										}
									}else{
										$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente '.$row['CDCLIEEXTERNO'].' '.$row['NMRAZSOCCLIE'].' nao pode ser cadastrado.'. " O CEP informado nao existe. ".'|'));
									}
								}
								
							}else{
								$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente '.$row['CDCLIEEXTERNO'].' '.$row['NMRAZSOCCLIE'].' nao pode ser cadastrado.'. " O CEP informado nao existe. ".'|'));
							}
						} else {
							// Cliente está cadastrado mas não possui código externo.
							
							// if (empty($codClie[0]['CDCLIEEXTERNO'])){
							// 	$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente '.$row['CDCLIENTE'].' '.$codClie[0]['NMRAZSOCCLIE'].' ja cadastrado no sistema, atualize seu codigo externo '.$row['CDCLIEEXTERNO'].'.|'));
							// } else {
							// 	$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente '.$row['CDCLIENTE'].' '.$codClie[0]['NMRAZSOCCLIE'].' ja cadastrado no sistema com codigo externo '.$codClie[0]['CDCLIEEXTERNO'].' ao inves de '.$row['CDCLIEEXTERNO'].' entao confira os codigos externos.|'));
							// }
							
							if (empty($codClie[0]['CDCLIEEXTERNO'])){
							
								$queryCodClieExt = <<<SQL3
										SELECT NRSEQWEBSERVICE, CDCLIENTE 
										  FROM CLIEPEDWEB
										 WHERE (CDCLIENTE = :P_CDCLIENTE)
SQL3;
								$codClieAux = $this->getConnection($connection)->fetchAll($queryCodClieExt, array(':P_CDCLIENTE' => $row['CDCLIENTE']));
								
								
								if(empty($codClieAux)){
									$queryInsereAux = <<<SQL4
											INSERT INTO CLIEPEDWEB (NRORG,    NRSEQWEBSERVICE,    CDCLIENTE,    DSEMAILCLIE,    CDCLIEEXTERNO)
															VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, :P_DSEMAILCLIE, :P_CDCLIEEXTERNO)
SQL4;
										$auxInserido = $this->getConnection($connection)->executeUpdate($queryInsereAux, array(':P_NRORG'           => $row['NRORG'],
																											   ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																											   ':P_CDCLIENTE'       => $row['CDCLIENTE'],
																											   ':P_DSEMAILCLIE'     => $row['DSEMAILCLIE'],
																											   ':P_CDCLIEEXTERNO'   => $row['CDCLIEEXTERNO']));
																													                     
			                    	$queryInsereSync = <<<SQL5
													INSERT INTO CLIEWEBSYNC (NRORG,    NRSEQWEBSERVICE,    CDCLIENTE,    DTULTALTCLIE, IDATUALIZADO)
																VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, SYSDATE,      'N')
SQL5;
									$SyncInserido = $this->getConnection($connection)->executeUpdate($queryInsereSync, array(':P_NRORG'           => $row['NRORG'],
																								 	     ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																								 	     ':P_CDCLIENTE'       => $row['CDCLIENTE']));
								}else{
									$queryUpdateClienteExterno = <<<SQL6
													UPDATE CLIEPEDWEB
													   SET CDCLIEEXTERNO = :P_CDCLIEEXTERNO, DSEMAILCLIE = :P_DSEMAILCLIE
													 WHERE (CDCLIENTE    = :P_CDCLIENTE)
														AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
														AND (NRORG = :P_NRORG)     
													   
SQL6;
									$updateClienteExterno = $this->getConnection($connection)->executeUpdate($queryUpdateClienteExterno, array(':P_CDCLIEEXTERNO'   => $row['CDCLIEEXTERNO'],
																												':P_DSEMAILCLIE'     => $row['DSEMAILCLIE'],
																											   ':P_CDCLIENTE'       => $row['CDCLIENTE'],
																											   ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																											   ':P_NRORG'           => $row['NRORG']));
								}
								
								
																													                     
							} else {
								
								$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente '.$row['CDCLIENTE'].' '.$codClie[0]['NMRAZSOCCLIE'].' ja cadastrado no sistema com codigo externo '.$codClie[0]['CDCLIEEXTERNO'].' ao inves de '.$row['CDCLIEEXTERNO'].' entao confira os codigos externos.|'));
																
							}
							
						}
					}catch(\Exception $e){
						$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente '.$row['CDCLIEEXTERNO'].' '.$row['NMRAZSOCCLIE'].' nao pode ser cadastrado.|'.' '.$e->getMessage().'|'));
					}
				} else {
					$row['CDCLIEEXTERNO'] = $cliente[0]['CDCLIENTE'];
				}

			} else {
				$row['CDCLIEEXTERNO'] = $clienteExt[0]['CDCLIENTE'];
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaVendedor é a função que valida o vendedor.
*******************************************************************************/
	
	private function validaVendedor($row, $connection){
		$result =  array( "valido" => true);
		$queryVend = <<<SQL
			SELECT CDVENDEDOR
			  FROM VENDEDOR
			 WHERE (CDVENDEDOR = :P_CDVENDEDOR)
			   AND (NRORG      = :P_NRORG     )
SQL;
		if($row['CDVENDEDOR'] == null){
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Vendedor nao enviado no pedido.|'));
		}else{
			$vend = $this->getConnection($connection)->fetchAll($queryVend, array(':P_CDVENDEDOR' => $row['CDVENDEDOR'],
																  ':P_NRORG'      => $row['NRORG']));
			if(empty($vend)){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Vendedor '.$row['CDVENDEDOR'].' nao encontrado.|'));
			}
		}
		return $result;
	}
	
/*******************************************************************************
	validaItemPedido é a função que valida os produtos.
*******************************************************************************/
	
	private function validaItemPedido(&$row, $connection){
		$result =  array( "valido" => true, 'validation' => array());
		foreach ($row['ITENS'] as &$itemRow) {
			
			if($itemRow['CDPRODEXTERNO'] == null){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Codigo externo do produto nao enviado no pedido.|'));
			} else {
				$queryProd = <<<SQL
					SELECT CDPRODUTO
					  FROM PRODPEDWEB
					 WHERE (CDPRODEXTERNO	= :P_CDPRODEXTERNO)
					   AND (NRORG       	= :P_NRORG        )
					   AND (NRSEQWEBSERVICE	= :P_NRSEQWEBSERVICE)
					   
SQL;
				$prodExt = $this->getConnection($connection)->fetchAll($queryProd, array(':P_CDPRODEXTERNO'    => $itemRow['CDPRODEXTERNO'],
																						 ':P_NRORG'            => $row['NRORG'],
																						 ':P_NRSEQWEBSERVICE'  => $row['NRSEQWEBSERVICE']));

			// var_dump($prodExt);
				/*$queryProd = <<<SQL
					SELECT PW.CDPRODUTO, PW.CDPRODEXTERNO, P.NMPRODUTO, PW.NRSEQWEBSERVICE
					  FROM PRODPEDWEB PW, PRODUTO P
					 WHERE (PW.CDPRODEXTERNO = :P_CDPRODEXTERNO)
					   AND (PW.NRORG         = :P_NRORG        )
					   AND (PW.CDPRODUTO = P.CDPRODUTO)
					   AND (PW.NRSEQWEBSERVICE	= :P_NRSEQWEBSERVICE)
SQL;
				$prodExt = $this->getConnection($connection)->fetchAll($queryProd, array(':P_CDPRODEXTERNO' => $itemRow['CDPRODEXTERNO'],
																   ':P_NRORG'         => $row['NRORG']));*/

				$quantItens = count($prodExt);
				
				// ERRO DE VRDSITPED, verificar se não tem mais de um produto cadastrado com o mesmo codigo do site
				// var_dump('prod', $itemRow['CDPRODEXTERNO'], 'qtde', $quantItens);
				
				if($quantItens > 1){
					$this->divideItem($row, $itemRow, $quantItens, $prodExt);
				}
				if(empty($prodExt)){
					$queryProd = <<<SQL1
						SELECT PR.CDPRODUTO
						FROM PRODPEDWEB PR, PRODUTO P
						WHERE PR.CDPRODUTO = P.CDPRODUTO
						AND (P.CDARVPROD   = :P_CDPRODEXTERNO)
						AND (PR.NRORG           = :P_NRORG )
						AND (PR.NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
SQL1;
					 
					/*$numPos = strlen($itemRow['CDPRODEXTERNO']);
					$zeros = '0';
					$aux3 = '0';
					$novoCdprodexterno;
					if($numPos < 10){
						$aux = 10 - $numPos;
						$aux2 = 1;
						while($aux2 < $aux){
							$zeros = $zeros.$aux3;
							$aux2 ++;
						}
						$novoCdprodexterno = $zeros.$itemRow['CDPRODEXTERNO'];
						$itemRow['CDPRODEXTERNO'] = $novoCdprodexterno;
					}*/
					$prod = $this->getConnection($connection)->fetchAll($queryProd, array(':P_CDPRODEXTERNO' => $itemRow['CDPRODEXTERNO'],
																	   ':P_NRORG'         => $row['NRORG'],
																	   ':P_NRSEQWEBSERVICE'  => $row['NRSEQWEBSERVICE']));
					if(empty($prod)){
						$result['valido'] = false;
						$result['validation'][] = ' Produto '.$itemRow['CDPRODEXTERNO'].' '.$itemRow['DSPRODUTO'].' nao encontrado.|';
					} else {
						$itemRow['CDPRODEXTERNO'] = $prod[0]['CDPRODUTO'];
					
					}
					
				} else if($quantItens == 1){
					$itemRow['CDPRODEXTERNO'] = $prodExt[0]['CDPRODUTO'];
				}
				
				/*INICIO DA VALIDAÇÃO DE PRODUTO ATIVO*/
				$queryProdAtivo = <<<SQL2
					SELECT CDPRODUTO
					  FROM PRODUTO
					 WHERE (CDPRODUTO = :P_CDPRODEXTERNO)
					   AND (NRORG     = :P_NRORG        )
					   AND (IDATIVO = 'N')
SQL2;

				$ProdAtivo = $this->getConnection($connection)->fetchAll($queryProdAtivo, array(':P_CDPRODEXTERNO' => $itemRow['CDPRODEXTERNO'],
																   ':P_NRORG'         => $row['NRORG']));

				if($ProdAtivo){
					$result['valido'] = false;
					$result['validation'][] = ' Produto '.$itemRow['CDPRODEXTERNO'].' inativo.|';
				}

				/*FIM DA VALIDAÇÃO DE PRODUTO ATIVO*/
					
				if($itemRow['QTITEMPED']<=0){
					$result['valido'] = false;
					$result['validation'][] = ' Quantidade do produto '.$itemRow['CDPRODEXTERNO'].' deve ser maior que zero.|';
				}
				if($itemRow['CDITPEDEXTERNO']==null){
					$result['valido'] = false;
					$result['validation'][] = ' Codigo externo do item do produto '.$itemRow['CDPRODEXTERNO'].' nao enviado.|';
				}

				$VRPREUNITPED = floatval(str_replace(",",".", $itemRow['VRPREUNITPED']));
				$QTITEMPED = floatval(str_replace(",",".", $itemRow['QTITEMPED']));
				$VRDESITPED = floatval(str_replace(",",".", $itemRow['VRDESITPED']));
				
				if ($row['PRECOSITE'] == 'N') {
					$queryProdClie = <<<SQL2
						SELECT NRORG, CDPRODUTO, '' AS CDPRECOBASE, VRPRECOPROD AS VALOR, 0 AS VRPROMO, '1' AS OPCAO
						  FROM TABPRECLIE
						 WHERE (CDPRODUTO = :P_CDPRODUTO)
						   AND (CDCLIENTE = :P_CDCLIENTE)
						   AND (NRORG     = :P_NRORG    )
						   AND (TO_CHAR(SYSDATE,'DD/MM/YYYY') BETWEEN DTVALINI AND DTVALFIN)
						
						UNION
						
						SELECT IB.NRORG, IB.CDPRODUTO, IB.CDPRECOBASE, IB.VRITEPREBASE AS VALOR, XP.VRTOTALPROMO AS VRPROMO, '2' AS OPCAO
						  FROM ITEMPREBASE IB,
						      (
						      SELECT I.CDPRECOBASE,
						             I.CDPRODUTO,
						             B.VRTOTALPROMO
						        FROM ITEMPREBASE I, PROMOPRBASE B
						       WHERE (I.CDPRECOBASE  = :P_CDPRECOBASE)
						         AND (B.CDPRECOBASE  = I.CDPRECOBASE )
						         AND (B.CDPRODUTO    = I.CDPRODUTO   )
						         AND (B.DTINIVALIPB  = I.DTINIVALIPB )
						         AND ((B.IDDIASPROMO = (TO_CHAR(SYSDATE,'D')))OR(B.IDDIASPROMO ='8'))
						         AND (TO_CHAR(SYSDATE,'DD/MM/YYYY') BETWEEN B.DTINIPROMO AND B.DTFINPROMO)
						     ) XP
						 WHERE (IB.NRORG       = :P_NRORG      )
						   AND (IB.CDPRECOBASE = :P_CDPRECOBASE)
						   AND (IB.CDPRODUTO   = :P_CDPRODUTO  )
						   AND (IB.CDPRODUTO   = XP.CDPRODUTO   (+))
						   AND (IB.CDPRECOBASE = XP.CDPRECOBASE (+))
						 ORDER BY OPCAO
SQL2;
					$prodClie = $this->getConnection($connection)->fetchAll($queryProdClie, array(':P_CDPRODUTO'   => $itemRow['CDPRODEXTERNO'],
																			':P_CDCLIENTE'   => $row['CDCLIEEXTERNO'],
																			':P_CDPRECOBASE' => $row['CDPRECOBASE'],
																			':P_NRORG'       => $row['NRORG']));
					if (empty($prodClie)) {
						$result['valido'] = false;
						$result['validation'][] = ' Produto '.$itemRow['CDPRODEXTERNO'].' '.$itemRow['DSPRODUTO'].' nao tem valor na tabela de preco '.$row['CDPRECOBASE'].'.|';
					}
				} else {
					if($VRPREUNITPED<=0){
						$result['valido'] = false;
						$result['validation'][] = ' Valor do produto '.$itemRow['CDPRODEXTERNO'].' deve ser maior que zero.|';
					}
				}
				
				$valorTotalItem = $VRPREUNITPED * $QTITEMPED;  

				if($valorTotalItem == $VRDESITPED){
				// var_dump($itemRow['CDITPEDEXTERNO'], $itemRow['CDPRODEXTERNO'], $itemRow['DSPRODUTO'], $itemRow['VRDESITPED'], $valorTotalItem, '######');
					$result['valido'] = false;
					$result['validation'][] = ' Valor do desconto do item '.$itemRow['CDPRODEXTERNO'].' deve ser diferente do valor total do item.|';
				}				

			}
		};
		// var_dump($row['ITENS']);die;
		return $result;
	}

/*******************************************************************************
	divideItem é a função que monta o array de itens para inserir no pedido.
*******************************************************************************/

	private function divideItem($row, $itemRow, $quantItens, $prodExt){
		$precoProduto = $itemRow['VRPREUNITPED'];
		$cdprodexterno = $itemRow['CDPRODEXTERNO'];
		$dsproduto = $itemRow['DSPRODUTO'];
		$cditpedexterno = $itemRow['CDITPEDEXTERNO'];
		$precoItem = $precoProduto / $quantItens;
		$aux = 0;
		
		for($aux = 0; $aux < $quantItens; $aux++){
			array_push($row['ITENS'], $itens = [
	            'CDITPEDEXTERNO' => $cditpedexterno,
	            'CDPRODUTO' 	 => $prodExt[$aux]['CDPRODUTO'],
	            'CDPRODEXTERNO'  => $prodExt[$aux]['CDPRODUTO'],
	            'QTITEMPED'      => '1',
	            'VRPREUNITPED'   => $precoItem,
	            'DSPRODUTO'      => $dsproduto,
	            'DSITEMPED'      => '',
	            'DTENTITPED'     => ''
	        ]);
        	$cditpedexterno++;
		}
		
		$this->mudaIndiceArray($row, $quantItens);
	}

/*******************************************************************************
	mudaIndiceArray é a função que muda os índices do array.
*******************************************************************************/

	private function mudaIndiceArray($row, $quantItens){
		$posVelha = 0;
		$posNova = 1;
		
		for($aux = 0; $aux < $quantItens; $aux++){
			$row['ITENS'][$posVelha] = $row['ITENS'][$posNova];
			$posVelha++;
			$posNova++;
		}
		unset($row['ITENS'][$posVelha]);
		
		return($row);
	}


/*******************************************************************************
	validaEndereco é a função que valida o endereço.
*******************************************************************************/
	
	private function validaEndereco($row){
		$result =  array( "valido" => true);
		if(strlen($row['DSVENDEDOR']) > 60){
			$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Vendedor nao enviado no pedido.|'));
		}else{
			$vend = $this->getConnection($row)->fetchAll($queryVend, array(':P_CDVENDEDOR' => $row['CDVENDEDOR'],
																  ':P_NRORG'      => $row['NRORG']));
			if(empty($vend)){
				$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Vendedor '.$row['CDVENDEDOR'].' nao encontrado.|'));
			}
		}
		
		return $result;
	}
	
	
/*******************************************************************************
	insertCompPed é a função que insere a composição dos produtos.
*******************************************************************************/

	// private function insertCompPed($row, $nrPedido, $itemRow, $nrItemPed, $response, $connection){
	private function insertCompPed($row, $nrPedido, $itemRow, $nrItemPed, $response, $newConnection){

		// $newConnection = $this->getConnection($connection);

		$PesoPedBruto   = 0;
		$PesoPedLiquido = 0;

		try {
			
			$queryRotFab = <<<SQL
				SELECT CDSUBPRODUTO, QTSUBPRODROT, NRSEQPROD, CDGRUPOCOMP
				  FROM ROTFABRICA
				 WHERE (CDPRODUTO = :P_CDPRODUTO)
				   AND (NRORG     = :P_NRORG    )
SQL;
			// $rotFab = $this->getConnection($connection)->fetchAll($queryRotFab, array(':P_NRORG'     => $row['NRORG'],
			$rotFab = $newConnection->fetchAll($queryRotFab, array(':P_NRORG'     => $row['NRORG'],
																	  ':P_CDPRODUTO' => $itemRow['CDPRODEXTERNO']));

			$PesoCompBruto   = 0;
			$PesoCompLiquido = 0;
			foreach ($rotFab as $roteiro) {
				$queryCompPeso = <<<SQL1
					SELECT CDARVPROD, NMPRODUTO, SGUNIDADE, NVL(VRPESOBRUTPR, 0) AS VRPESOBRUTPR,
					       NVL(VRPESOLIQUPR, 0) AS VRPESOLIQUPR
					  FROM PRODUTO
					 WHERE (CDPRODUTO = :P_CDSUBPRODUTO)
					   AND (NRORG     = :P_NRORG       )
SQL1;
				// $compPeso = $this->getConnection($connection)->fetchAll($queryCompPeso, array(':P_CDSUBPRODUTO' => $roteiro['CDSUBPRODUTO'],
				$compPeso = $newConnection->fetchAll($queryCompPeso, array(':P_CDSUBPRODUTO' => $roteiro['CDSUBPRODUTO'],
																			  ':P_NRORG'        => $row['NRORG']));

				if((!empty($compPeso[0]['VRPESOBRUTPR']))&&(!empty($compPeso[0]['VRPESOLIQUPR']))){
					$PesoCompBruto   = $PesoCompBruto   + $compPeso[0]['VRPESOBRUTPR'];
					$PesoCompLiquido = $PesoCompLiquido + $compPeso[0]['VRPESOLIQUPR'];
				}

				$queryValor = <<<SQL2
					SELECT VRITEPREBASE
					  FROM ITEMPREBASE
					 WHERE (CDPRODUTO     = :P_CDSUBPRODUTO)
					   AND (NRORG         = :P_NRORG       )
					   AND (CDPRECOBASE   = :P_CDPRECOBASE )
					   AND (DTINIVALIPB  <= SYSDATE        )
					   AND ((DTFIMVALIPB >= SYSDATE) OR (DTFIMVALIPB IS NULL))
SQL2;
				// $valor = $this->getConnection($connection)->fetchAll($queryValor, array(':P_CDSUBPRODUTO' => $roteiro['CDSUBPRODUTO'],
				$valor = $newConnection->fetchAll($queryValor, array(':P_CDSUBPRODUTO' => $roteiro['CDSUBPRODUTO'],
																	    ':P_CDPRECOBASE'  => $row['CDPRECOBASE'],
																	    ':P_NRORG'        => $row['NRORG']));
				
            	if(!empty($valor[0]['VRITEPREBASE'])){

					$queryCompPed = <<<SQL3
						INSERT INTO COMPITEMPED (NRORG, CDFILIAL, NRPEDIDO, NRITEMPED, CDPRODUTO,
						                         CDPRODCOMPED, QTITCOMPPROD, VRPREUNICOMP, CDGRUPOCOMP,
						                         NRSEQPROD)
						                 VALUES (:P_NRORG, :P_CDFILIAL, :P_NRPEDIDO, LPAD(:P_NRITEMPED, 10, '0'), :P_CDPRODUTO,
						                         :P_CDSUBPRODUTO, :P_QTSUBPRODROT, :P_VRITEPREBASE, :P_CDGRUPOCOMP,
						                         :P_NRSEQPROD)
SQL3;

					// $CompPed = $this->getConnection($connection)->executeUpdate($queryCompPed, array(
					$CompPed = $newConnection->executeUpdate($queryCompPed, array(
																					 ':P_NRORG'        => $row['NRORG'],
																					 ':P_CDFILIAL'     => $row['CDFILIAL'],
																					 ':P_NRPEDIDO'     => $nrPedido,
																					 ':P_NRITEMPED'    => $nrItemPed,
																					 ':P_CDPRODUTO'    => $itemRow['CDPRODEXTERNO'],
																					 ':P_CDSUBPRODUTO' => $roteiro['CDSUBPRODUTO'],
																					 ':P_QTSUBPRODROT' => $roteiro['QTSUBPRODROT'],
																					 ':P_VRITEPREBASE' => $valor[0]['VRITEPREBASE'],
																					 ':P_CDGRUPOCOMP'  => $roteiro['CDGRUPOCOMP'],
																					 ':P_NRSEQPROD'    => $roteiro['NRSEQPROD']));
				}
			}
			$PesoItemBruto   = 0;
			$PesoItemLiquido = 0;
			$queryPeso = <<<SQL4
				SELECT CDARVPROD, NMPRODUTO, SGUNIDADE, NVL(VRPESOBRUTPR, 0) AS VRPESOBRUTPR,
				       NVL(VRPESOLIQUPR, 0) AS VRPESOLIQUPR
				  FROM PRODUTO
				 WHERE (CDPRODUTO = :P_CDPRODUTO)
				   AND (NRORG     = :P_NRORG    )
SQL4;
			// $peso = $this->getConnection($connection)->fetchAll($queryPeso, array(':P_CDPRODUTO' => $itemRow['CDPRODEXTERNO'],
			$peso = $newConnection->fetchAll($queryPeso, array(':P_CDPRODUTO' => $itemRow['CDPRODEXTERNO'],
																  ':P_NRORG'     => $row['NRORG']));

			if((!empty($peso[0]['VRPESOBRUTPR']))&&(!empty($peso[0]['VRPESOLIQUPR']))){
				$PesoItemBruto   = $PesoItemBruto   + $peso[0]['VRPESOBRUTPR'];
				$PesoItemLiquido = $PesoItemLiquido + $peso[0]['VRPESOLIQUPR'];
			}
			
		// O sistema deve priorizar o peso da composição do produto.
        	if(((!empty($PesoCompBruto))&&($PesoCompBruto <> 0))&&((!empty($PesoCompLiquido))&&($PesoCompLiquido <> 0))){
        		$PesoPedBruto   = $PesoCompBruto;
        		$PesoPedLiquido = $PesoCompLiquido;
        	} elseif (((!empty($PesoCompBruto))&&($PesoCompBruto <> 0))&&((!empty($PesoCompBruto))&&($PesoCompBruto <> 0))) {
        		$PesoPedBruto   = $PesoItemBruto;
        		$PesoPedLiquido = $PesoItemLiquido;
        	}
        		
        	if((!empty($PesoPedBruto))&&(!empty($PesoPedLiquido))){

				$queryAtuPeso = <<<SQL5
					UPDATE PEDIDO
					   SET VRPBRUVOLPED = (SELECT NVL(VRPBRUVOLPED,0) AS VRPBRUVOLPED
                                             FROM PEDIDO
											WHERE (NRORG    = :P_NRORG   )
											  AND (CDFILIAL = :P_CDFILIAL)
											  AND (NRPEDIDO = :P_NRPEDIDO)) + :P_VRPESOBRUTPR,
					       VRPLIQVOLPED = (SELECT NVL(VRPLIQVOLPED,0) AS VRPLIQVOLPED
                                             FROM PEDIDO
											WHERE (NRORG    = :P_NRORG   )
											  AND (CDFILIAL = :P_CDFILIAL)
											  AND (NRPEDIDO = :P_NRPEDIDO)) + :P_VRPESOLIQUPR
					 WHERE (NRORG    = :P_NRORG   )
					   AND (CDFILIAL = :P_CDFILIAL)
					   AND (NRPEDIDO = :P_NRPEDIDO)
SQL5;
				// $atuPeso = $this->getConnection($connection)->fetchAll($queryAtuPeso, array(':P_NRORG'        => $row['NRORG'],
				$atuPeso = $newConnection->fetchAll($queryAtuPeso, array(':P_NRORG'        => $row['NRORG'],
																			':P_CDFILIAL'     => $row['CDFILIAL'],
																			':P_NRPEDIDO'     => $nrPedido,
																			':P_VRPESOBRUTPR' => $PesoPedBruto,
																			':P_VRPESOLIQUPR' => $PesoPedLiquido));
			}

		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
	}
	
/*******************************************************************************
	insertObs é a função que insere a observação do cliente no pedido.
*******************************************************************************/
	
	private function insertObs($nrPedido, $row, $connection){
		$queryObs = <<<SQL
			SELECT DSOBSERVCLIE
			  FROM OBSERVCLIE
			 WHERE (CDCLIENTE = :P_CDCLIENTE)
			   AND (NRORG     = :P_NRORG    )
SQL;
		$Obs = $this->getConnection($connection)->fetchAll($queryObs, array(':P_NRORG'     => $row['NRORG'],
													  ':P_CDCLIENTE' => $row['CDCLIEEXTERNO']));

		if(!empty($Obs)){
			$queryObsPed = <<<SQL1
				INSERT INTO OBSPEDIDO (NRORG, CDFILIAL, NRPEDIDO, TXOBSPED)
				VALUES (:P_NRORG, :P_CDFILIAL, :P_NRPEDIDO, :P_TXOBSPED)
SQL1;
			$ObsPed = $this->getConnection($connection)->executeUpdate($queryObsPed, array(
																':P_NRORG'    => $row['NRORG'],
																':P_CDFILIAL' => $row['CDFILIAL'],
																':P_NRPEDIDO' => $nrPedido,
																':P_TXOBSPED' => $Obs[0]['DSOBSERVCLIE']));
		}
	}
	
/*******************************************************************************
	insertObsPedido é a função que insere a observação no pedido.
*******************************************************************************/
	
	// private function insertObsPedido($nrPedido, $row, $connection){ 
	private function insertObsPedido($nrPedido, $row, $newConnection){
			
		// $newConnection = $this->getConnection($connection);
			
			// modificar DSPEDCLI
			// $row['DSPEDCLI'] = ' ';

			$queryObsPed = <<<SQL1
				INSERT INTO OBSPEDIDO (NRORG, CDFILIAL, NRPEDIDO, TXOBSPED)
				VALUES (:P_NRORG, :P_CDFILIAL, :P_NRPEDIDO, :P_TXOBSPED)
SQL1;
			// $ObsPed = $this->getConnection($connection)->executeUpdate($queryObsPed, array(
			$ObsPed = $newConnection->executeUpdate($queryObsPed, array(
																':P_NRORG'    => $row['NRORG'],
																':P_CDFILIAL' => $row['CDFILIAL'],
																':P_NRPEDIDO' => $nrPedido,
																':P_TXOBSPED' => bin2hex($row['DSPEDCLI'])));
	}
	
	
	
	
/*******************************************************************************
	insertPrazo é a função que insere o prazo do pedido.
*******************************************************************************/
	
	// private function insertPrazo($nrPedido, $row, $connection){
	private function insertPrazo($nrPedido, $row, $newConnection){
		
		// $newConnection = $this->getConnection($connection);
	
		$queryTotal = <<<SQL2
				SELECT I.CDFILIAL, 
						I.NRPEDIDO, 
						TO_CHAR((I.VRITEM + NVL(E.VRENCARGO,0) + NVL(IM.VRIMPOSTO,0))) VRTOTALPED,
						I.VRITEM
				  FROM (SELECT I.NRORG, I.CDFILIAL, I.NRPEDIDO,
				               SUM((I.QTITEMPED * I.VRPREUNITPED) - (I.VRDESITPED)) VRITEM
				          FROM ITEMPEDIDO I
				         GROUP BY I.NRPEDIDO, I.CDFILIAL, I.NRORG) I,
				       (SELECT E.CDFILIAL, E.NRPEDIDO,
				               SUM(CASE EN.IDENCARGO WHEN 'A' 
				                                     THEN TO_CHAR(NVL(E.VRENCARGOPED,0))
				                                     WHEN 'D' 
				                                     THEN TO_CHAR(NVL(E.VRENCARGOPED,0) * -1)
				                                     ELSE '0'
				                                     END) VRENCARGO
				          FROM ENCARGOPED E, ENCARGO EN
				         WHERE (E.CDENCARGO = EN.CDENCARGO)
				         GROUP BY E.CDFILIAL, E.NRPEDIDO) E,
				       (SELECT IP.CDFILIAL, IP.NRPEDIDO,
				               SUM(CASE IM.IDTRATIMPO WHEN 'A' 
				                                      THEN TO_CHAR(NVL(IP.VRACREDESCITPED,0))
				                                      WHEN 'D' 
				                                      THEN TO_CHAR(NVL(IP.VRACREDESCITPED,0) * -1)
				                                      ELSE '0'
				                                      END) VRIMPOSTO
				          FROM IMPOSTO IM, IMPITEMPEDIDO IP
				         WHERE (IP.CDIMPOSTO = IM.CDIMPOSTO)
				         GROUP BY IP.CDFILIAL, IP.NRPEDIDO) IM
				 WHERE (I.CDFILIAL = E.CDFILIAL  (+))
				   AND (I.NRPEDIDO = E.NRPEDIDO  (+))
				   AND (I.CDFILIAL = IM.CDFILIAL (+))
				   AND (I.NRPEDIDO = IM.NRPEDIDO (+))
				   AND (I.NRORG    = :P_NRORG       )
				   AND (I.CDFILIAL = :P_CDFILIAL    )
				   AND (I.NRPEDIDO = :P_NRPEDIDO    )
SQL2;
		// $total = $this->getConnection($connection)->fetchAll($queryTotal, array(':P_NRORG'    => $row['NRORG'],
		$total = $newConnection->fetchAll($queryTotal, array(':P_NRORG'    => $row['NRORG'],
																':P_CDFILIAL' => $row['CDFILIAL'],
																':P_NRPEDIDO' => $nrPedido));
																
		
		$Dias = 0;
		$Parcela = 0;
		$queryModpgto = <<<SQL
			SELECT
               NRDIASMODPGTO,
               CDMODPGTO,
               TO_CHAR(VRPERCMODPGTO) AS VRPERCMODPGTO
            FROM
               PRAZOMODPGTO
            WHERE CDMODPGTO = :P_CDMODPGTO
            AND NRORG = :P_NRORG
            ORDER BY
               CDMODPGTO, NRDIASMODPGTO

SQL;
		// $mod = $this->getConnection($connection)->fetchAll($queryModpgto, array(':P_NRORG'     => $row['NRORG'],
		$mod = $newConnection->fetchAll($queryModpgto, array(':P_NRORG'     => $row['NRORG'],
																				':P_CDMODPGTO' => $row['CDMODPGTO']));
		if(!empty($mod)){																		

			foreach ($mod as $itmod) {
                $Dias = $itmod['NRDIASMODPGTO'];
                if(!empty($total)){
                        $Parcela = $total[0]['VRTOTALPED'] * $itmod['VRPERCMODPGTO']/100;

						/* MUDANÇA DE REPLACE - GLOBO GRAVA FLOAT COM ',' E QUEBRA COM '.' */
                        // $Parcela = str_replace(".",",",$Parcela);
                        // $Parcela = str_replace(",",".",$Parcela);
                        // MUDANÇA KEEP 1

                }
                $queryPrazo = <<<SQL1
                        INSERT INTO PRAZOPGTOPED (CDFILIAL, NRPEDIDO, NRDIASPGTOPED, VRPERCPGTOPED, NRORG, VRPARCELA)
                        VALUES (:P_CDFILIAL, :P_NRPEDIDO, :P_NRDIASPGTOPED, :P_VRPERCMODPGTO, :P_NRORG, :P_VRPARCELA)
SQL1;
                // $prazo = $this->getConnection($connection)->executeUpdate($queryPrazo, array(':P_NRORG'         => $row['NRORG'],
                $prazo = $newConnection->executeUpdate($queryPrazo, array(':P_NRORG'         => $row['NRORG'],
                                                                                                     ':P_CDFILIAL'      => $row['CDFILIAL'],
                                                                                                     ':P_NRPEDIDO'      => $nrPedido,
                                                                                                     ':P_NRDIASPGTOPED' => $Dias,
                                                                                                     ':P_VRPARCELA'     => $Parcela,                                                                                                                                         
                                                                                                     ':P_VRPERCMODPGTO' => $itmod['VRPERCMODPGTO']));
            }
		}
																		 
	}
	
/*******************************************************************************
	insertFrete é a função que insere o frete do pedido.
*******************************************************************************/
	
	// private function insertFrete($nrPedido, $row, $connection){
	private function insertFrete($nrPedido, $row, $newConnection){
	
		// $newConnection = $this->getConnection($connection);
	
		$queryEncargo = <<<SQL
			SELECT E.CDENCARGO
			  FROM ENCARGONFE N, ENCARGO E
			 WHERE (N.CDENCARGONFE = '01'          )
			   AND (E.CDENCARGONFE = N.CDENCARGONFE)
SQL;
		// $encargo = $this->getConnection($connection)->fetchAll($queryEncargo);
		$encargo = $newConnection->fetchAll($queryEncargo);

		if(!empty($encargo)){
			$queryFrete = <<<SQL1
					INSERT INTO ENCARGOPED (NRORG, CDFILIAL, NRPEDIDO, CDENCARGO, VRENCARGOPED)
					VALUES (:P_NRORG, :P_CDFILIAL, :P_NRPEDIDO, :P_CDENCARGO, :P_VRENCARGOPED)
SQL1;
			try{
				// $frete = $this->getConnection($connection)->executeUpdate($queryFrete, array(
				$frete = $newConnection->executeUpdate($queryFrete, array(
																			 ':P_NRORG'         => $row['NRORG'],
																			 ':P_CDFILIAL'      => $row['CDFILIAL'],
																			 ':P_NRPEDIDO'      => $nrPedido,
																			 ':P_CDENCARGO'     => $encargo[0]['CDENCARGO'],
																			 ':P_VRENCARGOPED'  => $row['VRFRETE']));
			}catch(\Exception $e){
				$vrFrete = str_replace(".", ",", $row['VRFRETE']);
				// $frete = $this->getConnection($connection)->executeUpdate($queryFrete, array(
				$frete = $newConnection->executeUpdate($queryFrete, array(
																			 ':P_NRORG'         => $row['NRORG'],
																			 ':P_CDFILIAL'      => $row['CDFILIAL'],
																			 ':P_NRPEDIDO'      => $nrPedido,
																			 ':P_CDENCARGO'     => $encargo[0]['CDENCARGO'],
																			 ':P_VRENCARGOPED'  => $vrFrete));
			}
			
			
																		 
																		 
		}
	}
	
/*******************************************************************************
	insertDesconto é a função que insere o desconto do pedido.
*******************************************************************************/
	
	// private function insertDesconto($nrPedido, $row, $connection){
	private function insertDesconto($nrPedido, $row, $newConnection){
		
		// $newConnection = $this->getConnection($connection);
	
		$queryEncargo = <<<SQL
			SELECT E.CDENCARGO
			  FROM ENCARGONFE N, ENCARGO E
			 WHERE (N.CDENCARGONFE = '03'          )
			   AND (E.CDENCARGONFE = N.CDENCARGONFE)
SQL;
		// $encargo = $this->getConnection($connection)->fetchAll($queryEncargo);
		$encargo = $newConnection->fetchAll($queryEncargo);
		if(!empty($encargo)){
			$queryEncargo = <<<SQL1
				INSERT INTO ENCARGOPED (NRORG, CDFILIAL, NRPEDIDO, CDENCARGO, VRENCARGOPED)
				VALUES (:P_NRORG, :P_CDFILIAL, :P_NRPEDIDO, :P_CDENCARGO, :P_VRENCARGOPED)
SQL1;
			try{
				// $desconto = $this->getConnection($connection)->executeUpdate($queryEncargo, array(
				$desconto = $newConnection->executeUpdate($queryEncargo, array(
																			  ':P_NRORG'         => $row['NRORG'],
																			  ':P_CDFILIAL'      => $row['CDFILIAL'],
																			  ':P_NRPEDIDO'      => $nrPedido,
																			  ':P_CDENCARGO'     => $encargo[0]['CDENCARGO'],
																		  	  ':P_VRENCARGOPED'  => $row['VRDESCONTO']));
			}catch(\Exception $e){
				$vrDesc = str_replace(".", ",", $row['VRDESCONTO']);
				// $desconto = $this->getConnection($connection)->executeUpdate($queryEncargo, array(
				$desconto = $newConnection->executeUpdate($queryEncargo, array(
																				  ':P_NRORG'         => $row['NRORG'],
																				  ':P_CDFILIAL'      => $row['CDFILIAL'],
																				  ':P_NRPEDIDO'      => $nrPedido,
																				  ':P_CDENCARGO'     => $encargo[0]['CDENCARGO'],
																			  	  ':P_VRENCARGOPED'  => $vrDesc));
			}
			
		}
	}
	
/*******************************************************************************
	insertItem é a função que insere os itens do pedido.
*******************************************************************************/
	
	// private function insertItem($itemRow, $nrPedido, $row, $nrItemPed, $statItem, $cdOper, $cdVend, $entregaItem, $response, $connection, $entrega){
	private function insertItem($itemRow, $nrPedido, $row, $nrItemPed, $statItem, $cdOper, $cdVend, $entregaItem, $response, $newConnection, $entrega){
		
		// $newConnection = $this->getConnection($connection);
		
		if(empty($itemRow['DTENTITPED'])){
			$dataItem = $entregaItem;
		} else {
			$dataItem = $itemRow['DTENTITPED'].' 08:00:00';
		}

		if($itemRow['VRPREUNITPED']<=0){
			$queryPrecoBaseCli = <<<SQL
				SELECT NVL(T.NRDIASADMI, 0) AS NRDIASADMI
				  FROM MODPGTO M, TIPORECE T
				 WHERE (M.CDTIPORECE = T.CDTIPORECE)
				   AND (M.CDMODPGTO  = :P_CDMODPGTO)
				   AND (M.NRORG      = :P_NRORG    )
				 ORDER BY M.CDMODPGTO
SQL;
			// $mod = $this->getConnection($connection)->fetchAll($queryPrecoBaseCli, array(':P_NRORG'    => $row['NRORG'],
			$mod = $newConnection->fetchAll($queryPrecoBaseCli, array(':P_NRORG'    => $row['NRORG'],
																		':P_CDMODPGTO' => $row['CDMODPGTO']));

		}
		
		$queryPedido = <<<SQL0
			SELECT * FROM PEDIDO
				WHERE (NRPEDIDO = :P_NRPEDIDO)
				AND (CDFILIAL = :P_CDFILIAL)
SQL0;
		// $ped = $this->getConnection($connection)->fetchAll($queryPedido, array(':P_NRPEDIDO'  => $nrPedido,
		$ped = $newConnection->fetchAll($queryPedido, array(':P_NRPEDIDO'  => $nrPedido,
															    			   ':P_CDFILIAL'  => $row['CDFILIAL']));
		if(!empty($ped)){
			$queryBuscaItem = <<<SQL
				SELECT * FROM ITEMPEDIDO
				WHERE (NRPEDIDO  = :P_NRPEDIDO)
				   AND (NRITEMPED      = :P_NRITEMPED)
				   AND (NRORG      = :P_NRORG)
				   AND (CDFILIAL      = :P_CDFILIAL)

SQL;
	
	
			// $item = $this->getConnection($connection)->fetchAll($queryBuscaItem, array(':P_NRPEDIDO'  => $nrPedido,
			$item = $newConnection->fetchAll($queryBuscaItem, array(':P_NRPEDIDO'  => $nrPedido,
																    				   ':P_NRITEMPED' => $nrItemPed,
																    				   ':P_NRORG' => $row['NRORG'],
																    				   ':P_CDFILIAL'  => $row['CDFILIAL']));
																    				   
			
			if(empty($item)){
				$queryItem = <<<SQL
					INSERT INTO ITEMPEDIDO
					   (CDFILIAL, NRPEDIDO, NRITEMPED, IDSITITEMPED, CDPRODUTO,
					    QTITEMPED, VRPREUNITPED, QTEXPITEMPED, IDITPEDSEMQTDIS,
					    IDPRECOPROM, DTENTITPED, NRORG, DSITEMPED, VRDESITPED)
					VALUES
					   (:P_CDFILIAL, :P_NRPEDIDO, LPAD(:P_NRITEMPED, 10, '0'), :P_IDSITITEMPED, 
					    :P_CDPRODEXTERNO, :P_QTITEMPED, :P_VRPREUNITPED, '0', 'N',
					    'N', TO_DATE(NVL(:P_DTENTITPED, SYSDATE),'DD/MM/YYYY HH24:MI:SS'), :P_NRORG, :P_DSITEMPED, :P_VRDESITPED)
					    
SQL;

				$vr = floatval(str_replace(",",".", $itemRow['VRPREUNITPED']));
				$vrDesconto = floatval($itemRow['VRDESITPED']);

                /* alteração para validar vrpreunitped*/
                // $vr = str_replace(".",",",$vr);
                // $vrDesconto = str_replace(".",",",$vrDesconto);
                /* fim alteração */
				
                $qtItem = floatval($itemRow['QTITEMPED']);
				
                // $itens = $this->getConnection($connection)->executeUpdate($queryItem, array(':P_NRORG'         => $row['NRORG'],
				$itens = $newConnection->executeUpdate($queryItem, array(':P_NRORG'         => $row['NRORG'],
																			':P_CDFILIAL'      => $row['CDFILIAL'],
																			':P_NRPEDIDO'      => $nrPedido,
																			':P_NRITEMPED'     => $nrItemPed,
																			':P_IDSITITEMPED'  => $statItem,
																			':P_QTITEMPED'     => $qtItem,
																			':P_VRPREUNITPED'  => $vr,
																			':P_CDPRODEXTERNO' => $itemRow['CDPRODEXTERNO'],
																			':P_DSITEMPED'     => $itemRow['DSITEMPED'],
																			':P_DTENTITPED'    => $dataItem,
																			':P_VRDESITPED'    => $vrDesconto));
																			
				
															
				$queryItExt = <<<SQL1
					INSERT INTO ITPEDWEBEXT (NRORG, NRSEQWEBSERVICE, CDFILIAL, NRPEDIDO, NRITEMPED, CDPEDEXTERNO, CDITPEDEXTERNO)
					VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDFILIAL, :P_NRPEDIDO, LPAD(:P_NRITEMPED, 10, '0'), :P_CDPEDEXTERNO, :P_CDITPEDEXTERNO)
					
SQL1;
				// $itExt = $this->getConnection($connection)->executeUpdate($queryItExt, array(
				$itExt = $newConnection->executeUpdate($queryItExt, array(
																			 ':P_NRORG'           => $row['NRORG'],
																			 ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																			 ':P_CDFILIAL'        => $row['CDFILIAL'],
																			 ':P_NRPEDIDO'        => $nrPedido,
																			 ':P_NRITEMPED'       => $nrItemPed,
																			 ':P_CDPEDEXTERNO'    => $row['PEDEXTERNO'],
																			 ':P_CDITPEDEXTERNO'  => $itemRow['CDITPEDEXTERNO']));
															
				// $this->insertCompPed($row, $nrPedido, $itemRow, $nrItemPed, $response, $connection);
				$this->insertCompPed($row, $nrPedido, $itemRow, $nrItemPed, $response, $newConnection);
				try{
					
					$vrpreunitpedProc = str_replace(".",",",$itemRow['VRPREUNITPED']);
					// $itemRow['VRPREUNITPED'] = $valorFormat;
					$params = array();
			        //----Gera comissão para o vendedor
			        // $procedure = new StoredProcedure($this->getConnection($connection), 'GERA_COMISSAOVEND', $params);
			        $procedure = new StoredProcedure($newConnection, 'GERA_COMISSAOVEND', $params);
			        $procedure->addParam(new Param('P_CDFILIAL'    , Param::PARAM_INPUT, $row['CDFILIAL']                           , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_NRPEDIDO'    , Param::PARAM_INPUT, $nrPedido                                  , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_CDVENDEDOR'  , Param::PARAM_INPUT, $cdVend                                    , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_CDOPERADOR'  , Param::PARAM_INPUT, $cdOper                                    , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_NRITEMPED'   , Param::PARAM_INPUT, str_pad($nrItemPed, 10, "0", STR_PAD_LEFT) , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_IDSITITEMPED', Param::PARAM_INPUT, $statItem                                  , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_CDPRODUTO'   , Param::PARAM_INPUT, $itemRow['CDPRODEXTERNO']                  , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_VRPREUNITPED', Param::PARAM_INPUT, $vrpreunitpedProc /*$itemRow['VRPREUNITPED']*/, Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_OLDCDVENDE'  , Param::PARAM_INPUT, null                                       , Param::PARAM_TYPE_STR));
			        // $procedure->addParam(new Param('P_NRORG'       , Param::PARAM_INPUT, $row['NRORG']                              , Param::PARAM_TYPE_INT));
			        
			        $params = [
			        	'P_CDFILIAL' => $row['CDFILIAL'],
			        	'P_NRPEDIDO'    => $nrPedido,
			        	'P_CDVENDEDOR'  => $cdVend,
			        	'P_CDOPERADOR'  => $cdOper,
			        	'P_NRITEMPED'   => str_pad($nrItemPed, 10, "0", STR_PAD_LEFT),
			        	'P_IDSITITEMPED'=> $statItem,
			        	'P_CDPRODUTO'   => $itemRow['CDPRODEXTERNO'],
			        	'P_VRPREUNITPED'=> $vrpreunitpedProc/*$itemRow['VRPREUNITPED']*/,
			        	'P_OLDCDVENDE'  => null          
			        ];
			        
			        $procedure->execute($params); //Invoca a procedure para gerar comissão
				}catch(\Exception $e){
					// $vrpreunitpedProc = str_replace(",",".",$itemRow['VRPREUNITPED']);
					// $itemRow['VRPREUNITPED'] = $valorFormat;
					$params = array();
			        //----Gera comissão para o vendedor
			        // $procedure = new StoredProcedure($this->getConnection($connection), 'GERA_COMISSAOVEND', $params);
			        $procedure = new StoredProcedure($newConnection, 'GERA_COMISSAOVEND', $params);
			        $procedure->addParam(new Param('P_CDFILIAL'    , Param::PARAM_INPUT, $row['CDFILIAL']                           , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_NRPEDIDO'    , Param::PARAM_INPUT, $nrPedido                                  , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_CDVENDEDOR'  , Param::PARAM_INPUT, $cdVend                                    , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_CDOPERADOR'  , Param::PARAM_INPUT, $cdOper                                    , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_NRITEMPED'   , Param::PARAM_INPUT, str_pad($nrItemPed, 10, "0", STR_PAD_LEFT) , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_IDSITITEMPED', Param::PARAM_INPUT, $statItem                                  , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_CDPRODUTO'   , Param::PARAM_INPUT, $itemRow['CDPRODEXTERNO']                  , Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_VRPREUNITPED', Param::PARAM_INPUT, $itemRow['VRPREUNITPED'], Param::PARAM_TYPE_STR));
			        $procedure->addParam(new Param('P_OLDCDVENDE'  , Param::PARAM_INPUT, null                                       , Param::PARAM_TYPE_STR));
			        // $procedure->addParam(new Param('P_NRORG'       , Param::PARAM_INPUT, $row['NRORG']                              , Param::PARAM_TYPE_INT));
			        
			        $params = [
			        	'P_CDFILIAL' => $row['CDFILIAL'],
			        	'P_NRPEDIDO'    => $nrPedido,
			        	'P_CDVENDEDOR'  => $cdVend,
			        	'P_CDOPERADOR'  => $cdOper,
			        	'P_NRITEMPED'   => str_pad($nrItemPed, 10, "0", STR_PAD_LEFT),
			        	'P_IDSITITEMPED'=> $statItem,
			        	'P_CDPRODUTO'   => $itemRow['CDPRODEXTERNO'],
			        	'P_VRPREUNITPED'=> $itemRow['VRPREUNITPED'],
			        	'P_OLDCDVENDE'  => null          
			        ];
			        
			        $procedure->execute($params); //Invoca a procedure para gerar comissão
				}
				
			}
	    }
	}
    
/*******************************************************************************
	insertPedido é a função que insere os pedidos.
*******************************************************************************/
    
    private function getNewCode($connection) {
    	$newCode = new NewCode($connection);
    	
    	return $newCode;
    }
    
    private function generateNewCode($connection, $cdcontador, $nrorg) {
    	$newCode = $this->getNewCode($connection);
    	
    	return $newCode->getCodeByTableName($cdcontador, $nrorg, 1, 10, false);
    }

    // private function insertPedido($row, $response, $connection){
    private function insertPedido($row, $response, $connection){
    	
    	$newConnection = $this->getConnection($connection);
    	
    	$newConnection->beginTransaction();
    	
    	try{
    		
    		// SET NLS NUMERIC CHARACTERS
			$nls = "ALTER SESSION SET NLS_NUMERIC_CHARACTERS = '. '";
			$newConnection->executeUpdate($nls, array());
    		
			// Chama a procedure de novo código
			$aux = 'PEDIDO'.$row['CDFILIAL'];
	        // $nrPedido = $this->generateNewCode($this->getConnection($connection), $aux, $row['NRORG']);
    	    $nrPedido = $this->generateNewCode($newConnection, $aux, $row['NRORG']);
	        // Select que busca informações adicionais do cliente
			$insJurTrans = '';
			$tipoTrans   = '';
			$idTrans     = '';
			$tpPgFrete   = '9';
			$tipoEnd     = 'P';
			$razaoClie   = '';
			$insJurClie  = '';
			$insEstClie  = '';
			$cdClieVend  = '';
			$queryClieAdic = <<<SQL5
				SELECT NRINSJURTRAN, IDTPIJURTRAN, CDTIPTRANS, IDPGFRETTRANCLI, IDENDEMISCLI,
				       NMRAZSOCCLIE, NRINSJURCLIE, NRINSESTCLIE, CDVENDEDOR
				  FROM CLIENTE
				 WHERE (CDCLIENTE  = :P_CDCLIENTE)
				   AND (NRORG      = :P_NRORG    )
SQL5;
			// $ClieAdic = $this->getConnection($connection)->fetchAll($queryClieAdic, array(':P_NRORG'     => $row['NRORG'],
			$ClieAdic = $newConnection->fetchAll($queryClieAdic, array(':P_NRORG'     => $row['NRORG'],
																							':P_CDCLIENTE' => $row['CDCLIEEXTERNO']));
	
			if (!empty($ClieAdic[0]['NRINSJURTRAN'])	&&
				!empty($ClieAdic[0]['IDTPIJURTRAN'])	&&
				!empty($ClieAdic[0]['CDTIPTRANS']))
			{
				$insJurTrans = $ClieAdic[0]['NRINSJURTRAN'];
				$idTrans     = $ClieAdic[0]['IDTPIJURTRAN'];
				$tipoTrans   = $ClieAdic[0]['CDTIPTRANS'];
				if (!empty($ClieAdic[0]['IDPGFRETTRANCLI'])){
					$tpPgFrete = $ClieAdic[0]['IDPGFRETTRANCLI'];
				}
			}
			if (!empty($ClieAdic[0]['CDVENDEDOR'])){
				$cdClieVend = $ClieAdic[0]['CDVENDEDOR'];
			}else{
				$cdClieVend = $row['CDVENDEDOR'];
			}
			if (!empty($ClieAdic[0]['NMRAZSOCCLIE'])&&!empty($ClieAdic[0]['NRINSJURCLIE'])){
				$razaoClie  = $ClieAdic[0]['NMRAZSOCCLIE'];
				$insJurClie = $ClieAdic[0]['NRINSJURCLIE'];
				if (!empty($ClieAdic[0]['NRINSESTCLIE'])){
					$insEstClie = $ClieAdic[0]['NRINSESTCLIE'];
				}
				if (!empty($ClieAdic[0]['IDENDEMISCLI'])){
					$tipoEnd = $ClieAdic[0]['IDENDEMISCLI'];
				}else{
					$tipoEnd = 'P';
				}
			}
	        // Select que busca informações do endereço do cliente
	        $endereco  = '';
			$codCidade = '';
			$cidade    = '';
			$sigEstado = '';
			$estado    = '';
			$codPais   = '';
			$pais      = '';
			$telefone  = null;
			$email     = null;
			$cep       = null;
			$bairro    = null;
			$queryEndClie = <<<SQL4
				SELECT ED.DSENDECLIE,      -- Endereço;
				       ED.NRTELECLIE,      -- Telefone;
				       ED.NRTELECLIE1,     -- Telefone;
				       ED.DSEMAILCLIE,     -- E-mail
				       ED.NRCEPCLIE,       -- CEP;
				       ED.NMBAIRCLIE,      -- Bairro;
				       ED.CDMUNICIPIO,     -- Código Cidade;
				       MU.NMMUNICIPIO,     -- Cidade;
				       ED.SGESTADO,        -- Sigla Estado;
				       ES.NMESTADO,        -- Estado;
				       ED.CDPAIS,          -- Código País;
				       PA.NMPAIS           -- País;
				  FROM ENDECLIE ED, PAIS PA, ESTADO ES, MUNICIPIO MU
				 WHERE (CASE WHEN ((SELECT COUNT(1) FROM ENDECLIE 
	                         WHERE CDCLIENTE = ED.CDCLIENTE
	                          AND NRORG = ED.NRORG
	                          AND IDTPENDECLIE = 'T') = 1
	                        )
	            THEN 'T'
	            ELSE 'P'
	          END) =  ED.IDTPENDECLIE
				   AND (ED.CDCLIENTE    = :P_CDCLIENTE   )
				   AND (ED.NRORG        = :P_NRORG       )
				   AND (ED.CDPAIS       = PA.CDPAIS      (+))
				   AND (ED.SGESTADO     = ES.SGESTADO    (+))
				   AND (ED.CDMUNICIPIO  = MU.CDMUNICIPIO (+))
				 ORDER BY ED.IDTPENDECLIE
SQL4;
			// $EndClie = $this->getConnection($connection)->fetchAll($queryEndClie, array(':P_NRORG'        => $row['NRORG'],
			$EndClie = $newConnection->fetchAll($queryEndClie, array(':P_NRORG'        => $row['NRORG'],
																	    ':P_CDCLIENTE'    => $row['CDCLIEEXTERNO']));
			
			// NOVA VALIDAÇÃO PARA ENDEREÇO DE ENTREGA
			$queryUtilizaEndentr = <<<SQL7
				SELECT IDUTENDENTR
				  FROM PEDIDOWEB
				 WHERE (NRORG           = :P_NRORG          )
				   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
SQL7;
			
			$utilizaEndentr = $newConnection->fetchAll($queryUtilizaEndentr, array(':P_NRORG'           => $row['NRORG'],
																				   ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE']));
			
			$idutendentr = $utilizaEndentr[0]['IDUTENDENTR'];
			
			if($idutendentr == 'S'){
				
				if(isset($row['ENDERECOENTREGA'])){
					$row['CEP'] = $row['ENDERECOENTREGA']['NRCEPCLIE'];
					
					$responseEndEntrega = $this->findAddress($row, $connection);
					
					if(is_array($responseEndEntrega) && !empty($responseEndEntrega)){
						
						$enderecoEntr = $responseEndEntrega;
						
						$endereco  = $enderecoEntr['DSLOGRADOURO'].' '.$enderecoEntr['DSENDERECO'].', '.$row['ENDERECOENTREGA']['NRENDERECO'];
						$codCidade = $enderecoEntr['CDMUNICIPIO'];
						$cidade    = $enderecoEntr['NMMUNICIPIO'];
						$sigEstado = $enderecoEntr['SGESTADO'];
						$estado    = $enderecoEntr['NMESTADO'];
						$codPais   = $enderecoEntr['CDPAIS'];
						$pais      = $enderecoEntr['NMPAIS'];
						
						$telefone  = ' ';
						$email     = ' ';
						$cep       = $row['ENDERECOENTREGA']['NRCEPCLIE'];
						$bairro    = $enderecoEntr['NMBAIRRO'];
						
					}else{
						if (!empty($EndClie[0]['DSENDECLIE'])	&&
							!empty($EndClie[0]['NRCEPCLIE'])	&&
							!empty($EndClie[0]['CDMUNICIPIO'])	&&
							!empty($EndClie[0]['SGESTADO'])		&&
							!empty($EndClie[0]['CDPAIS'])){
								
							$endereco  = $EndClie[0]['DSENDECLIE'];
							$codCidade = $EndClie[0]['CDMUNICIPIO'];
							$cidade    = $EndClie[0]['NMMUNICIPIO'];
							$sigEstado = $EndClie[0]['SGESTADO'];
							$estado    = $EndClie[0]['NMESTADO'];
							$codPais   = $EndClie[0]['CDPAIS'];
							$pais      = $EndClie[0]['NMPAIS'];
							if (!empty($EndClie[0]['NRTELECLIE'])){
								$telefone  = $EndClie[0]['NRTELECLIE'];	
							} else {
								$telefone  = ' ';
							}
							if (!empty($EndClie[0]['DSEMAILCLIE'])){
								$email     = $EndClie[0]['DSEMAILCLIE'];	
							} else {
								$email    = ' ';	
							}
							if (!empty($EndClie[0]['NRCEPCLIE'])){
								$cep       = $EndClie[0]['NRCEPCLIE'];	
							} else {
								$cep    = ' ';	
							}
							if (!empty($EndClie[0]['NMBAIRCLIE'])){
								$bairro    = $EndClie[0]['NMBAIRCLIE'];
							} else {
								$bairro    = ' ';	
							}
						}
					}
				}else{
					if (!empty($EndClie[0]['DSENDECLIE'])	&&
						!empty($EndClie[0]['NRCEPCLIE'])	&&
						!empty($EndClie[0]['CDMUNICIPIO'])	&&
						!empty($EndClie[0]['SGESTADO'])		&&
						!empty($EndClie[0]['CDPAIS'])){
							
						$endereco  = $EndClie[0]['DSENDECLIE'];
						$codCidade = $EndClie[0]['CDMUNICIPIO'];
						$cidade    = $EndClie[0]['NMMUNICIPIO'];
						$sigEstado = $EndClie[0]['SGESTADO'];
						$estado    = $EndClie[0]['NMESTADO'];
						$codPais   = $EndClie[0]['CDPAIS'];
						$pais      = $EndClie[0]['NMPAIS'];
						if (!empty($EndClie[0]['NRTELECLIE'])){
							$telefone  = $EndClie[0]['NRTELECLIE'];	
						} else {
							$telefone  = ' ';
						}
						if (!empty($EndClie[0]['DSEMAILCLIE'])){
							$email     = $EndClie[0]['DSEMAILCLIE'];	
						} else {
							$email    = ' ';	
						}
						if (!empty($EndClie[0]['NRCEPCLIE'])){
							$cep       = $EndClie[0]['NRCEPCLIE'];	
						} else {
							$cep    = ' ';	
						}
						if (!empty($EndClie[0]['NMBAIRCLIE'])){
							$bairro    = $EndClie[0]['NMBAIRCLIE'];
						} else {
							$bairro    = ' ';	
						}
					}
				}

			}else{
				// IDENDEMISCLI
				if (!empty($EndClie[0]['DSENDECLIE'])	&&
					!empty($EndClie[0]['NRCEPCLIE'])	&&
					!empty($EndClie[0]['CDMUNICIPIO'])	&&
					!empty($EndClie[0]['SGESTADO'])		&&
					!empty($EndClie[0]['CDPAIS'])){
						
					$endereco  = $EndClie[0]['DSENDECLIE'];
					$codCidade = $EndClie[0]['CDMUNICIPIO'];
					$cidade    = $EndClie[0]['NMMUNICIPIO'];
					$sigEstado = $EndClie[0]['SGESTADO'];
					$estado    = $EndClie[0]['NMESTADO'];
					$codPais   = $EndClie[0]['CDPAIS'];
					$pais      = $EndClie[0]['NMPAIS'];
					if (!empty($EndClie[0]['NRTELECLIE'])){
						$telefone  = $EndClie[0]['NRTELECLIE'];	
					} else {
						$telefone  = ' ';
					}
					if (!empty($EndClie[0]['DSEMAILCLIE'])){
						$email     = $EndClie[0]['DSEMAILCLIE'];	
					} else {
						$email    = ' ';	
					}
					if (!empty($EndClie[0]['NRCEPCLIE'])){
						$cep       = $EndClie[0]['NRCEPCLIE'];	
					} else {
						$cep    = ' ';	
					}
					if (!empty($EndClie[0]['NMBAIRCLIE'])){
						$bairro    = $EndClie[0]['NMBAIRCLIE'];
					} else {
						$bairro    = ' ';	
					}
				}
			}
			// FIM NOVA VALIDAÇÃO
			
			
	        // Select que busca informações do parametro de pedidos
			$statItem   = '1';
			$statPed    = '1';
			$entrega    = '';
			$validade   = '';
			$utReserva  = 'N';
			$entregaItem = '';
			$queryParam = <<<SQL3
				SELECT IDLANCPED, NRDIASENTPED, IDUTRESELOTE, IDUTVALIPED, QTDIAVALIPED
				  FROM PARAMPEDIDO
				 WHERE (CDFILIAL = :P_CDFILIAL)
				   AND (NRORG    = :P_NRORG   )
SQL3;
			// $param = $this->getConnection($connection)->fetchAll($queryParam, array(':P_NRORG'    => $row['NRORG'],
			$param = $newConnection->fetchAll($queryParam, array(':P_NRORG'    => $row['NRORG'],
																	':P_CDFILIAL' => $row['CDFILIAL']));
															  
			if(!empty($param[0]['IDLANCPED'])){
				$statItem = $param[0]['IDLANCPED'];
				if(($statItem == '2')||($statItem == '3')){
					$statPed = '2';
				}
			}
			
			
			if(empty($row['DTENTPED'])){
				if(empty($param[0]['NRDIASENTPED'])){
					$entrega = date('d/m/Y');
					$entregaItem = date('d/m/Y H:i:s');
				}else{
					$entrega = date('d/m/Y', strtotime('+ '.$param[0]['NRDIASENTPED'].' days'));
					$entregaItem = date('d/m/Y H:i:s', strtotime('+ '.$param[0]['NRDIASENTPED'].' days'));
				}
			}else{
					$entrega = $row['DTENTPED'];
					$entregaItem = $row['DTENTPED'];
					$entregaItem = $entregaItem.' 08:00:00';
			}
			if($param[0]['IDUTVALIPED'] == 'S'){
				if(empty($param[0]['QTDIAVALIPED'])){
					$validade = date('d/m/Y');
				}else{
					$validade = date('d/m/Y', strtotime('+ '.$param[0]['QTDIAVALIPED'].' days'));
				}
			}
			
			//descomentar pra começar usar 
			$utReserva  = $param[0]['IDUTRESELOTE'];
			
	        // Select que busca informações da modalidade de pagamento do pedido
			$formPgto = '';
			$formTipo = '';
			$queryModpgto = <<<SQL2
				SELECT CDFORMPGTO, IDTPFORPGTOMOD, IDLANCPEDMOD
				  FROM MODPGTO
				 WHERE (CDMODPGTO  = :P_CDMODPGTO)
				   AND (NRORG      = :P_NRORG    )
SQL2;
			// $mod = $this->getConnection($connection)->fetchAll($queryModpgto, array(':P_NRORG'     => $row['NRORG'],
			$mod = $newConnection->fetchAll($queryModpgto, array(':P_NRORG'     => $row['NRORG'],
															        ':P_CDMODPGTO' => $row['CDMODPGTO']));
							
			if(!empty($mod[0]['CDFORMPGTO'])){
				$formPgto = $mod[0]['CDFORMPGTO'];
			}
			if(!empty($mod[0]['IDTPFORPGTOMOD'])){
				$formTipo = $mod[0]['IDTPFORPGTOMOD'];
			}
			if(!empty($mod[0]['IDLANCPEDMOD'])){
				$statItem = $mod[0]['IDLANCPEDMOD'];
				if(($statItem == '2')||($statItem == '3')){
					$statPed = '2';
				}
			}
			
			$queryModpgto = <<<SQL2
				SELECT *
				  FROM NOVOCODIGO
				 WHERE CDCONTADOR = 'PEDIDO0001' AND (NRORG      = :P_NRORG    )
SQL2;
			// $mod = $this->getConnection($connection)->fetchAll($queryModpgto, array(':P_NRORG'     => $row['NRORG']));
			$mod = $newConnection->fetchAll($queryModpgto, array(':P_NRORG'     => $row['NRORG']));

			
			/* NOVA IMPLEMENTAÇÃO PARA TIPO DE PEDIDO [1-PEDIDO / 2-ORÇAMENTO]*/
			$queryTipoPedido = <<<SQL6
				SELECT IDTIPOPEDIDOWEB
				  FROM PEDIDOWEB
				 WHERE (NRORG           = :P_NRORG          )
				   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
SQL6;
			// $tipoPedido = $this->getConnection($connection)->fetchAll($queryTipoPedido, array(':P_NRORG'           => $row['NRORG'],
			$tipoPedido = $newConnection->fetchAll($queryTipoPedido, array(':P_NRORG'           => $row['NRORG'],
																							  ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE']));
			
			if(!empty($tipoPedido)){
				$idtipopedido = $tipoPedido[0]['IDTIPOPEDIDOWEB'];
			}else{
				$idtipopedido = '1';
			}
			
			/* FIM NOVA IMPLEMENTAÇÃO PARA TIPO DE PEDIDO */
	
	        // Insere o pedido
			$queryPed = <<<SQL1
				INSERT INTO PEDIDO
				   (CDFILIAL, NRPEDIDO, NRORG, IDSITPEDIDO, CDCLIENTE, IDPRIOPED, 
				    DTPEDIDO, DTENTPED, CDMODPGTO, DTHRLANPED, CDOPELANPED, IDPEDIDOIMPR,
				    IDTIPOPEDIDO, IDORIGPED, CDPRECOBASE, IDENTRSAIDOP, CDTIPOOPER,
				    IDTPFORPGTPED, CDFORMPGTO, CDVENDEDOR,
				    IDTPIJURTRAN, NRINSJURTRAN, CDTIPTRANS, IDPGFRETTRAN, DTVALIPED, DSPEDVEN, NRORDEMCMPPED, NREXPEDIDO)
				VALUES 
				   (:P_CDFILIAL, :P_NRPEDIDO, :P_NRORG, :P_IDSITPEDIDO, :P_CDCLIEEXTERNO, '3', 
				    SYSDATE, TO_DATE(NVL(:P_DTENTPED, SYSDATE),'DD/MM/YYYY'),
				    :P_CDMODPGTO, SYSDATE, :P_CDOPELANPED, 'N', :P_IDTIPOPEDIDO, '2', :P_CDPRECOBASE,
				    :P_IDTIPOOPERWEB, :P_CDTIPOOPERWEB, :P_IDTPFORPGTPED, :P_CDFORMPGTO,
				    :P_CDVENDEDOR, :P_IDTPIJURTRAN, :P_NRINSJURTRAN, :P_CDTIPTRANS,
				    :P_IDPGFRETTRAN, TO_DATE(:P_DTVALIPED,'DD/MM/YYYY'), SUBSTR(:P_DSPEDVEN, 0, 200), :P_NRORDEMCMPPED, :P_NREXPEDIDO)
SQL1;
	
			// $pedidos = $this->getConnection($connection)->executeUpdate($queryPed, array(
			$pedidos = $newConnection->executeUpdate($queryPed, array(
																		 ':P_CDFILIAL'      => $row['CDFILIAL'],
							                                             ':P_NRPEDIDO'      => $nrPedido,
																		 ':P_NRORG'         => $row['NRORG'],
								                                         ':P_CDFORMPGTO'    => $formPgto,
								                                         ':P_IDTPFORPGTPED' => $formTipo,
								                                         ':P_IDSITPEDIDO'   => $statPed,
								                                         ':P_DTENTPED'      => $entrega,
								                                         ':P_DTVALIPED'     => $validade,
								                                         ':P_IDTPIJURTRAN'  => $idTrans,
								                                         ':P_NRINSJURTRAN'  => $insJurTrans,
								                                         ':P_CDTIPTRANS'    => $tipoTrans,
								                                         ':P_IDPGFRETTRAN'  => $tpPgFrete,
								                                         ':P_IDTIPOPEDIDO'  => $idtipopedido,
								                                         ':P_CDMODPGTO'     => $row['CDMODPGTO'],
								                                         ':P_CDVENDEDOR'    => $cdClieVend,
								                                         ':P_CDOPELANPED'   => $row['CDOPERADOR'],
								                                         ':P_CDPRECOBASE'   => $row['CDPRECOBASE'],
								                                         ':P_CDCLIEEXTERNO' => $row['CDCLIEEXTERNO'],
								                                         ':P_IDTIPOOPERWEB' => $row['IDTIPOOPERWEB'], 
								                                         ':P_CDTIPOOPERWEB' => $row['CDTIPOOPERWEB'],
								                                         ':P_DSPEDVEN'      => $row['DSPEDVEN'],
								                                         ':P_NRORDEMCMPPED' => $row['PEDEXTERNO'],
								                                         ':P_NREXPEDIDO'	=> isset($row['NREXPEDIDO']) ? $row['NREXPEDIDO'] : ''));

			// Grava o pedido para o webservice
			$queryPedExt = <<<SQL
				INSERT INTO PEDWEBEXT (NRORG, NRSEQWEBSERVICE, CDFILIAL, NRPEDIDO, CDPEDEXTERNO)
				VALUES(:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDFILIAL, :P_NRPEDIDO, :P_CDPEDEXTERNO)
SQL;
				// $ped = $this->getConnection($connection)->executeUpdate($queryPedExt, array(
				$ped = $newConnection->executeUpdate($queryPedExt, array(
																			':P_NRORG'           => $row['NRORG'],
																			':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																			':P_CDFILIAL'        => $row['CDFILIAL'],
																			':P_NRPEDIDO'        => $nrPedido,
																			':P_CDPEDEXTERNO'    => $row['PEDEXTERNO']));
			// Chama a função para inserir os itens do pedido
			$nrItemPed = '1';
			foreach ($row['ITENS'] as $itemRow) {
				// $this->insertItem($itemRow, $nrPedido, $row, $nrItemPed, $statItem, $row['CDOPERADOR'], $cdClieVend, $entregaItem, $response, $connection, $entrega);
				$this->insertItem($itemRow, $nrPedido, $row, $nrItemPed, $statItem, $row['CDOPERADOR'], $cdClieVend, $entregaItem, $response, $newConnection, $entrega);
				$nrItemPed ++;
			}
			
			// Chama a função para inserir o frete
			if(!$row['VRFRETE'] == null){
				// $this->insertFrete($nrPedido, $row, $connection);
				$this->insertFrete($nrPedido, $row, $newConnection);
			}
			// Chama a função para inserir o desconto
			if(!$row['VRDESCONTO'] == null){
				// $this->insertDesconto($nrPedido, $row, $connection);
				$this->insertDesconto($nrPedido, $row, $newConnection);
			}
			
			// Chama a função para inserir o prazo
			// $this->insertPrazo($nrPedido, $row, $connection);
			$this->insertPrazo($nrPedido, $row, $newConnection);

			//if(!$row['DSPEDCLI'] || $row['DSPEDCLI'] == null){
				// modificar DSPEDCLI
				// $row['DSPEDCLI'] = ' ';
			//}
	
			// chama a função para inserir a observação do pedido
			// $this->insertObsPedido($nrPedido, $row, $connection);
			$this->insertObsPedido($nrPedido, $row, $newConnection);

			// Chama a função para inserir a observação
		//	$this->insertObs($nrPedido, $row, $connection);
	
			// Insere o endereço do cliente no pedido
			if (!empty($endereco)&&!empty($cep)&&!empty($codCidade)&&!empty($sigEstado)&&!empty($codPais)){
				$queryEndPed = <<<SQL
					INSERT INTO DADOSENDPED (CDCLIENTE, NRORG, CDFILIAL, NRPEDIDO, NMRAZSOCPED, DSENDEPED, NRCEPPED, NRTELEPED, NRINSJURPED, NRINSESTPED, CDPAISPED, NMPAISPED, SGESTADOPED, NMESTADOPED, CDMUNICIPIOPED, NMMUNIPED, NMBAIRROPED)
					VALUES (:P_CDCLIENTE, :P_NRORG, :P_CDFILIAL, :P_NRPEDIDO, :P_NMRAZSOCPED, UPPER(:P_DSENDEPED), :P_NRCEPPED, :P_NRTELEPED, :P_NRINSJURPED, :P_NRINSESTPED, :P_CDPAISPED, :P_NMPAISPED, :P_SGESTADOPED, :P_NMESTADOPED, :P_CDMUNICIPIOPED, :P_NMMUNIPED, :P_NMBAIRROPED)
SQL;
					// $cdcliente;
					$endPed = $newConnection->executeUpdate($queryEndPed, array(
																				   ':P_CDCLIENTE'      => $row['CDCLIEEXTERNO'],
																				   ':P_NRORG'          => $row['NRORG'],
																				   ':P_CDFILIAL'       => $row['CDFILIAL'],
																				   ':P_NRPEDIDO'       => $nrPedido,
																				   ':P_NMRAZSOCPED'    => $razaoClie,
																				   ':P_DSENDEPED'      => $endereco,
																				   ':P_NRCEPPED'       => $cep,
																				   ':P_NRTELEPED'      => $telefone,
																				   ':P_NRINSJURPED'    => $insJurClie,
																				   ':P_NRINSESTPED'    => $insEstClie,
																				   ':P_CDPAISPED'      => $codPais,
																				   ':P_NMPAISPED'      => $pais,
																				   ':P_SGESTADOPED'    => $sigEstado,
																				   ':P_NMESTADOPED'    => $estado,
																				   ':P_CDMUNICIPIOPED' => $codCidade,
																				   ':P_NMMUNIPED'      => $cidade,
																				   ':P_NMBAIRROPED'    => $bairro));
				
				
				// $this->insereEnderecoEntr($connection, $row['CDCLIENTE'], $codCidade, $sigEstado, $codPais, $endereco);
				$this->insereEnderecoEntr($newConnection, $row['CDCLIENTE'], $codCidade, $sigEstado, $codPais, $endereco);
				
			}
			//realiza a reserva do pedido
			if($utReserva == 'S' && $idtipopedido == '1'){ // tratar se utiliza reserva ou nao
				
				// $this->reservaPedido($row['CDFILIAL'], $nrPedido, $nrItemPed, 'S', $connection);
				$this->reservaPedido($row['CDFILIAL'], $nrPedido, $nrItemPed, 'S', $newConnection);
			}
			
			// throw new \Exception('Falha no pedido');
			
			$newConnection->commit();
		
    	}catch(\Exception $e){
			
			$newConnection->rollback();
			throw $e;
			
		}
		
	}
	
	/*
		Método para inserir locais de entrega para o cliente
	*/
	// public function insereEnderecoEntr($connection, $cdcliente, $codCidade, $sigEstado, $codPais, $endereco){
	public function insereEnderecoEntr($newConnection, $cdcliente, $codCidade, $sigEstado, $codPais, $endereco){
		try{
			
			// $newConnection = $this->getConnection($connection);
			
			/* Busca locais de entrega de acordo com o cliente e os dados de entrega */
			$queryEndEntrExistente = <<<SQL
				SELECT CDCLIENTE, CDMUNICIPIO, SGESTADO, CDPAIS, DSENDELOCALENTR
				  FROM LOCALENTRCLIENTE
				 WHERE (CDCLIENTE       			= :P_CDCLIENTE)
				 AND   (CDPAIS						= :P_CDPAIS)
				 AND   (SGESTADO					= :P_SGESTADO)
				 AND   (CDMUNICIPIO					= :P_CDMUNICIPIO)
				 AND   (UPPER(DSENDELOCALENTR)	= UPPER(:P_DSENDELOCALENTR))
SQL;
			$endEntrExistente = $newConnection->fetchAll($queryEndEntrExistente, array(':P_CDCLIENTE'			=> $cdcliente,
																					   ':P_CDPAIS'				=> $codPais,
																					   ':P_SGESTADO'			=> $sigEstado,
																					   ':P_CDMUNICIPIO'			=> $codCidade,
																					   ':P_DSENDELOCALENTR'		=> $endereco));
			
			/* Busca maior NRLOCALENTRCLIENTE da tabela de locais de entrega para novo codigo */
			$queryMaxLocalEntrcliente = <<<SQL1
				SELECT NVL(MAX(NRLOCALENTRCLIENTE)+1, 1) AS NRLOCALENTRCLIENTE 
				  FROM LOCALENTRCLIENTE
SQL1;
			$maxLocalEntrcliente = $newConnection->fetchAll($queryMaxLocalEntrcliente, array());
			
			/* Se o endereço de entrega enviado ainda não existir, é cadastrado. */
			if(empty($endEntrExistente)){
				
				/* Busca locais de entrega de acordo com o cliente e os dados de entrega */
				$queryInsEndEntr = <<<SQL2
					INSERT INTO LOCALENTRCLIENTE (NRLOCALENTRCLIENTE, CDCLIENTE, CDPAIS, SGESTADO, CDMUNICIPIO, DSENDELOCALENTR, DSLOCALENTRCLIENTE)
					VALUES(:P_NRLOCALENTRCLIENTE, :P_CDCLIENTE, :P_CDPAIS, :P_SGESTADO, :P_CDMUNICIPIO, UPPER(:P_DSENDELOCALENTR), :P_DSLOCALENTRCLIENTE)
SQL2;

					$newConnection->executeUpdate($queryInsEndEntr, array(':P_NRLOCALENTRCLIENTE'=> $maxLocalEntrcliente[0]['NRLOCALENTRCLIENTE'],
																				 ':P_CDCLIENTE'			=> $cdcliente,
																			     ':P_CDPAIS'			=> $codPais,
																			     ':P_SGESTADO'			=> $sigEstado,
																			     ':P_CDMUNICIPIO'		=> $codCidade,
																			     ':P_DSENDELOCALENTR'	=> $endereco,
																			     ':P_DSLOCALENTRCLIENTE'=> 'Integração'));
			}
			
		}catch(\Exception $e){
			throw $e;
		}
		
	}
	
/*******************************************************************************
	reservaPedido é a função que reserva os pedidos.
*******************************************************************************/
   
   //public function reservaPedido($cdfilial, $nrPedido, $nrItemPed, $todos, $connection){
   public function reservaPedido($cdfilial, $nrPedido, $nrItemPed, $todos, $newConnection){
   	
   		try{
   			
   			// var_dump($newConnection);die;
	
			// $newConnection->beginTransaction();
			
			$params = array();

	        // $procedure = new StoredProcedure($this->getConnection($connection), 'INSERE_RESERPRODPED', $params);
	        $procedure = new StoredProcedure($newConnection, 'INSERE_RESERPRODPED', $params);
	        $procedure->addParam(new Param('P_CDFILIAL'    , Param::PARAM_INPUT, $cdfilial, Param::PARAM_TYPE_STR));
	        $procedure->addParam(new Param('P_NRPEDIDO'    , Param::PARAM_INPUT, $nrPedido, Param::PARAM_TYPE_STR));
	        $procedure->addParam(new Param('P_NRITEMPED'   , Param::PARAM_INPUT, null, /*str_pad($nrItemPed, 10, "0", STR_PAD_LEFT) ,*/ Param::PARAM_TYPE_STR));
	        $procedure->addParam(new Param('P_TODOS'  , Param::PARAM_INPUT, $todos, Param::PARAM_TYPE_STR));
	  
			// $cdfilial = "";
	        // $params = [
	        // 	'P_CDFILIAL' => $cdfilial,
	        // 	'P_NRPEDIDO'    => $nrPedido,
	        // 	'P_NRITEMPED'   => str_pad($nrItemPed, 10, "0", STR_PAD_LEFT),
	        // 	'P_TODOS'=> $todos
	        // ];

	        $procedure->execute(); //Invoca a procedure para gerar reserva
	        // $newConnection->commit();

		}catch(\Exception $e){

			$newConnection->rollBack();
			throw $e;
		}
   	
   } 
   
   public function searchCEP($cep){
	    $response = file_get_contents('http://viacep.com.br/ws/'.$cep.'/json/');
	    $response = json_decode($response, true);
        $cepError = array_key_exists("erro", $response);
	    
        if ($response != false && !$cepError) {
	        return array(
	            'logradouro' => array_key_exists("logradouro", $response) ? $response["logradouro"] : "",
	            'bairro'     => array_key_exists("bairro", $response) ? $response["bairro"] : "",
	            'municipio'  => array_key_exists("localidade", $response) ? $response["localidade"] : "",
	            'uf'         => array_key_exists("uf", $response) ? $response["uf"] : "",
	            'cep'        => $response["cep"]
	        );
	    }
	    return false;
	}
	
	public function findAddress($row, $connection){
        $cep = $row['CEP'];
        $bairro = isset($row['NMBAIRCLIE'])? $row['NMBAIRCLIE'] : '';
    
        $retornoCorreios = $this->searchCEP($cep);
        if (is_array($retornoCorreios) && count($retornoCorreios) > 0) {
        	
        	/* 
        	 * BUSCA LOGRADOURO 
        	 */
            $params =  array();
            $params["DSLOGRADOURO"] = explode(' ', $retornoCorreios["logradouro"])[0];
    
            $queryLogradouro = "SELECT CDLOGRADOURO, DSLOGRADOURO
                                FROM LOGRADOURO
                                WHERE UPPER(DSLOGRADOURO) LIKE UPPER(:DSLOGRADOURO) || '%'";
            $logradouro = $this->getConnection($connection)->fetchAll($queryLogradouro, array(':DSLOGRADOURO' => $params["DSLOGRADOURO"]));

            if ($logradouro && count($logradouro) > 0) {
                $endereco['CDLOGRADOURO'] = $logradouro[0]["CDLOGRADOURO"];
                $endereco['DSLOGRADOURO'] = $logradouro[0]["DSLOGRADOURO"];
            }

            $endereco['DSENDERECO'] = (!isset($endereco['DSLOGRADOURO']) || 
                                        $retornoCorreios["logradouro"] == '') ? $retornoCorreios["logradouro"] : 
                                        substr($retornoCorreios["logradouro"], strlen($endereco['DSLOGRADOURO']) + 1);
			
			/* 
			 * BUSCA ESTADO 
			 */
            $params =  array();
            $params["SGESTADO"] = $retornoCorreios["uf"];
            
            $queryEstado = "SELECT SGESTADO, NMESTADO
			                FROM ESTADO
			                WHERE CDPAIS = '0055'
			                AND UPPER(SGESTADO) = UPPER(:SGESTADO)";
            $estado = $this->getConnection($connection)->fetchAll($queryEstado, array(':SGESTADO' => $params["SGESTADO"]));
            $estado = $estado[0];
            
            if ($estado && count($estado) > 0) {
                $endereco["CDPAIS"]   = '0055';
                $endereco["NMPAIS"]   = 'Brasil';
                $endereco["SGESTADO"] = $estado["SGESTADO"];
                $endereco["NMESTADO"] = $estado["NMESTADO"];

                $acentos = array(
                    'á'=>'a', 'à'=>'a', 'ã'=>'a', 'â'=>'a', 'ä'=>'a', 'é'=>'e', 'ê'=>'e', 'è'=>'e', 'ë'=>'e', 'í'=>'i', 'ì'=>'i', 'ï'=>'i',
                    'î'=>'i', 'ó'=>'o', 'ô'=>'o', 'ò'=>'o', 'õ'=>'o', 'ö'=>'o', 'ú'=>'u', 'ü'=>'u', 'ù'=>'u', 'û'=>'u', 'ç'=>'c', 'Á'=>'A',
                    'À'=>'A', 'Ã'=>'A', 'Â'=>'A', 'Ä'=>'A', 'É'=>'E', 'Ê'=>'E', 'È'=>'E', 'Ë'=>'E', 'Í'=>'I', 'Ì'=>'I', 'Ï'=>'I', 'Î'=>'I',
                    'Ó'=>'O', 'Ô'=>'O', 'Õ'=>'O', 'Ò'=>'O', 'Ö'=>'O', 'Ú'=>'U', 'Ù'=>'U', 'Û'=>'U', 'Ü'=>'U', 'Ç'=>'C'
                );

				/* 
				 * BUSCA MUNICIPIO 
				 */
				
                $params =  array();
                $params["SGESTADO"] = $endereco["SGESTADO"];
                $params["NMMUNICIPIO"] = $retornoCorreios["municipio"];
                $params["NMMUNICIPIO_SEMACENTO"] = strtr($retornoCorreios["municipio"], $acentos);

                $queryMunicipio = "SELECT NMMUNICIPIO, CDMUNICIPIO
			                	FROM MUNICIPIO
			                	WHERE CDPAIS = '0055'
			                	AND SGESTADO = :SGESTADO
			                	AND (UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIO)
			                    OR UPPER(NMMUNICIPIO) = UPPER(:NMMUNICIPIO_SEMACENTO))";
			                    
	            $municipio = $this->getConnection($connection)->fetchAll($queryMunicipio, array(':SGESTADO' => $params["SGESTADO"],
	            																				':NMMUNICIPIO' => $params["NMMUNICIPIO"],
	            																				':NMMUNICIPIO_SEMACENTO' => $params["NMMUNICIPIO_SEMACENTO"]));
	            $municipio = $municipio[0];
	            
                if (count($municipio) > 0) {
                    $endereco['NMMUNICIPIO'] = $municipio["NMMUNICIPIO"];
                    $endereco['CDMUNICIPIO'] = $municipio["CDMUNICIPIO"];
                    
                    if($retornoCorreios["bairro"] != "") {
                        $trueUpper = array(
                            'á'=>'A', 'à'=>'A', 'ã'=>'A', 'â'=>'A', 'ä'=>'A', 'é'=>'E', 'ê'=>'E', 'è'=>'E', 'ë'=>'Ë', 'í'=>'I', 'ì'=>'I', 'ï'=>'I',
                            'î'=>'I', 'ó'=>'O', 'ô'=>'O', 'ò'=>'O', 'õ'=>'O', 'ö'=>'O', 'ú'=>'U', 'ü'=>'U', 'ù'=>'U', 'û'=>'U', 'ç'=>'C'
                        );

                        $retornoCorreios["bairro"] = strtoupper(strtr($retornoCorreios["bairro"], $trueUpper));
                        $endereco['NMBAIRRO'] = $retornoCorreios["bairro"];
                    }else{
                        //para casos que o buscaCep nao traga bairro pega o bairro que o cliente enviar tratativa feita para integração de pedidos.
                        $endereco['NMBAIRRO'] = $bairro;
                    }
                    $endereco['CDBAIRRO'] = '';
                }
                else {
                    return "O município ".$params["NMMUNICIPIO"]." não foi carregado automaticamente porque não está cadastrado no sistema.";
                }
            }
            else {
                return "O estado ".$params["SGESTADO"]." não foi carregado automaticamente porque não está cadastrado no sistema.";
            }
            
            // var_dump($endereco);die;
            return $endereco;
    
        }else {
            return "CEP não encontrado.";
        }
    }
	
/*******************************************************************************
	registraPedido  é  a requisição responsável por validar e inserir o pedido e
	os itens do pedido.
	
	Recebe como parêmtro  o número da  organização, o código da filial, o código
	da modalidade  de  pagamento,  o  código do  operador, o código da tabela de
	preço, o código externo do pedido e o código externo do cliente. Um array de
	items com o código externo dos produtos, o código externo dos itens da órdem
	a quantidade e o preço dos produtos.
	
	Se qualquer uma  dessas  informações estiver nula o pedido não será inserido
	e  retornará  uma  mensagem  de erro avisando qual campo não foi encontrado.
*******************************************************************************/
	
	public function registraPedido($request, $response, $rows, $email_retorno1, $email_retorno2, $connection) {
		
		/* MUDANÇA-RESERVA */
		/* mudanças aplicadas:
		   
		   - $this->getConnection($connection) TO $newConnection;
		   
		   - PARAMETROS DAS FUNCOES RELACIONADAS AO INSERPEDIDOS DE $connection TO $newConnection;
		   
		   - FUNCAO $newConnection->beginTransaction(); ADICIONADA ANTES DO BLOCO TRY E DENTRO DO BLOCO TRY
		  
		*/
		
		// $newConnection = $this->entityManager->getConnection();
		// $newConnection = $this->getConnection($connection);
		// $newConnection->setAutoCommit(false);
		// $newConnection->beginTransaction();
		
		// ------------------------------------------------------
		
		$pedidosComErro =  array();
		$pedidosSemErro =  array();
		foreach ($rows as $row) {
			try{
				// var_dump($row['ITENS']);
				// $newConnection->beginTransaction();

				$validacoes = array();
				$validacoes[] = $this->validaPedido($row, $connection); 
				$validacoes[] = $this->validaFilial($row, $connection); 
				$validacoes[] = $this->validaModPgto($row, $connection); 
				$validacoes[] = $this->validaCliente($row, $request, $response, $rows, $connection); 
				$validacoes[] = $this->validaPrecoBase($row, $connection);
				$validacoes[] = $this->validaOperador($row,$connection);
				$validacoes[] = $this->validaTipoOper($row, $connection);
				$validacoes[] = $this->validaVendedor($row,$connection);

				$validacoes[] = $this->validaItemPedido($row, $connection);
				$estaValido = true;
				foreach ($validacoes as $validacao) {
					if(!$validacao['valido']) {
						$estaValido = false;
					}
				}
				if($estaValido){
					$this->insertPedido($row, $response, $connection);
					// $this->insertPedido($row, $response, $newConnection);
					$pedidosSemErro[] = array('PEDEXTERNO' => $row['PEDEXTERNO'].'|');
					// $newConnection->commit();
				} else {
					$pedidosComErro[] = array('validacoes' => $validacoes,  'PEDEXTERNO' => $row['PEDEXTERNO']);
				}
			} catch(\Exception $e) {
				// $newConnection->rollBack();
				$pedidosComErro[] = array('validacoes' => $validacoes,  'PEDEXTERNO' => $row['PEDEXTERNO'], "exception" => $e->getMessage());
			}
		};
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("pedidosComErro", $pedidosComErro));
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("pedidosComSucesso", $pedidosSemErro));
		
		$data = array("pedidosComErro" => $pedidosComErro, "pedidosComSucesso" => $pedidosSemErro);
		
		array_walk_recursive(
            $data, function (&$value) {
                $value = iconv('ISO-8859-1', 'UTF-8', $value);
            }
        );
		
		$data = json_encode($data, JSON_UNESCAPED_UNICODE);
		
		$find = array('\/',"valido",'"',";",":","{1}","}","{","validation","validacoes","true","false",",","MENSAGEM","[","]");
		$val = str_replace($find,'', $data);

		$replaceValues = [
			'pedidosComErro' => '<b>Pedidos Com Erro: </b><br />',
			'pedidosSemErro' => '<br/>Pedidos Sem Erro: <br />',
			'pedidosComSucesso' => '<br/><b>Pedidos Com Sucesso:</b><br />',
			'CDPEDEXTERNO' => '</br>CDPEDEXTERNO ',
			'PEDEXTERNO' => 'PEDEXTERNO: ',
			'1PEDEXTERNO' => 'PEDEXTERNO: ',
			'exceptionTransaction commit failed because the transaction has been marked for rollback only' => ' Nao foi cadastrado '
		];
		
		foreach ($replaceValues as $key => $value) {
			$val = str_replace($key, $value, $val);
		}
		
		$val = explode("|", $val);
		
	    $valUnique = array_unique($val);
	
	    $tabelaEmail = '';
	    foreach ($valUnique as $email ) {
	        $tabelaEmail .= '<tbody style="color: black; font-family: Verdana; line-height: 30px;"><tr><td>'. $email .'</td></tr></tbody>';
	    }
	    $subject = 'Detalhamento da Requisição de Pedidos';
	    $message = file_get_contents(__DIR__ . "/../Util/mail_template.html");
	    $message = str_replace('MAIL_CLIENTE', $rows[1]['Cliente'], $message);
	    $message = str_replace('MAIL_RETORNO', $tabelaEmail, $message);
	    $mail = new PHPMailer;
	    $mail->CharSet  = 'UTF-8';
	    $mail->isSMTP();                        // Set mailer to use SMTP
	    $mail->isHTML();
	    $mail->Host     = 'smtp.teknisa.com';   // Specify main and backup SMTP servers
	    $mail->SMTPAuth = true;                 // Enable SMTP authentication
	    $mail->Username = 'app@tecfood.com';    // SMTP username
	    $mail->Password = '@AppTecFood2015';    // SMTP password
	    $mail->From     = 'luiz.pereira@teknisa.com';
	    $mail->FromName = 'Pebbian WebService';
	    // $mail->addAddress($email_retorno1);
	    $mail->addAddress('luiz.pereira@teknisa.com');
	    // $mail->AddCC($email_retorno2);
	    $mail->Subject = $subject;
	    $mail->Body = $message;
	    
	    // COMENTAR SEND PARA TESTAR TEMPO DE RESPOSTA DO SERVIDOR
	    $mail->send();
    }
    
    public function gravaTeste($request, $response, $rows, $email_retorno1, $email_retorno2, $connection) {
	//	try{
			
			$this->insertTeste($row, $response, $connection);
			
	//	}catch(\Exception $e){
			
		//}

    }
    
    private function insertTeste($row, $response, $connection){
		
		// $conexao = $this->getConnection($connection);
		// $conexao->beginTransaction();
		
		try{
			// Grava o pedido para o webservice
			$queryParam = <<<SQL
				SELECT * FROM PARAMFILIAL WHERE NRORG = :P_NRORG AND CDFILIAL = :P_CDFILIAL
SQL;
				// $conexao->executeUpdate($queryPedExt, array());

//SQL1;
					// $clieAux = $this->getConnection($connection)->executeUpdate($query, array());

			$param = $this->getConnection($connection)->fetchAll($queryParam, array(':P_NRORG'    => '1308',
																':P_CDFILIAL' => '0001'));
			// var_dump($param);die;
																
		}catch(\Exception $e){
			
		}				 

		
	}
    
/*******************************************************************************
	registraClienteAux  é a função que insere os clientes externos em uma tabela
	auxiliar para 'de para' manual.
*******************************************************************************/
	
    
    public function registraClienteAux($response, $rows){
		
		// Separa os parâmetros necessários para a connection no banco do array principal.
		
		$queryClie = <<<SQL
			SELECT CDCLIENTE
			  FROM CLIEPEDWEBAUX
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDCLIENTE       = :P_CDCLIENTE      )
SQL;
		try{
			//begin
			
			foreach ($rows as $row) {
				$clie = $this->getConnection($row)->fetchAll($queryClie, array(':P_CDCLIENTE'       => $row['CDCLIENTE'],
																	  ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																	  ':P_NRORG'           => $row['NRORG']));
				if(empty($clie)){
					$stSobreNome = '';
					$stEmailClie = '';
					
					if (!empty($row['NMSOBRENOME'])){
						$stSobreNome = $row['NMSOBRENOME'];
					}else{
						$stSobreNome = ' ';
					}
					if (!empty($row['DSEMAILCLIE'])){
						$stEmailClie = $row['DSEMAILCLIE'];
					}else{
						$stEmailClie = ' ';
					}
					
					$queryClieAux = <<<SQL1
						INSERT INTO CLIEPEDWEBAUX (NRORG, NRSEQWEBSERVICE, CDCLIENTE, NMCLIENTE, NMSOBRENOME, DSEMAILCLIE)
						VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDCLIENTE, :P_NMCLIENTE, :P_NMSOBRENOME, :P_DSEMAILCLIE)
SQL1;
					$clieAux = $this->getConnection($row)->executeUpdate($queryClieAux, array(
																					 ':P_NRORG'           => $row['NRORG'],
																				     ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																				     ':P_CDCLIENTE'       => $row['CDCLIENTE'],
																				     ':P_NMCLIENTE'       => $row['NMCLIENTE'],
																				     ':P_NMSOBRENOME'     => $stSobreNome,
																				     ':P_DSEMAILCLIE'     => $stEmailClie));
																	      
					$clieSemErro[] = array('CDCLIENTE' => $row['CDCLIENTE']);
					
				} else {
					$clieComErro[] = array('CDCLIENTE' => $row['CDCLIENTE'], 'MENSAGEM' => 'Cliente ja cadastrado na tabela auxiliar.|');
				}
			}

			//commit
		}catch(\Exception $e){
			//rollback
			$clieComErro[] = array('CDCLIENTE' => $row['CDCLIENTE'], "exception" => $e->getMessage());
		}

		if (empty($clieComErro)) {
			$clieComErro = [];	
		}
		if (empty($clieSemErro)) {
			$clieSemErro = [];
		}
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("clieSemErro", $clieSemErro));
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("clieComErro", $clieComErro));	
	}
	
/*******************************************************************************
	registraProdutoAux é a  função que insere os produtos externos em uma tabela
	auxiliar para 'de para' manual.
*******************************************************************************/
	
	public function registraProdutoAux($response, $rows){
		
		// Separa os parâmetros necessários para a connection no banco do array principal.
		
		$queryProd = <<<SQL
			SELECT CDPRODUTO
			  FROM PRODPEDWEBAUX
			 WHERE (NRORG           = :P_NRORG          )
			   AND (NRSEQWEBSERVICE = :P_NRSEQWEBSERVICE)
			   AND (CDPRODUTO       = :P_CDPRODUTO      )
SQL;

		try{
			//begin
			foreach ($rows as $row) {
				$prod = $this->getConnection($row)->fetchAll($queryProd, array(':P_CDPRODUTO'       => $row['CDPRODUTO'],
																	  ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																	  ':P_NRORG'           => $row['NRORG']));
				if(empty($prod)){
					$queryProdAux = <<<SQL1
						INSERT INTO PRODPEDWEBAUX (NRORG, NRSEQWEBSERVICE, CDPRODUTO, NMPRODUTO)
						VALUES (:P_NRORG, :P_NRSEQWEBSERVICE, :P_CDPRODUTO, :P_NMPRODUTO)
SQL1;
					$prodAux = $this->getConnection($row)->executeUpdate($queryProdAux, array(
																					 ':P_NRORG'           => $row['NRORG'],
																				     ':P_NRSEQWEBSERVICE' => $row['NRSEQWEBSERVICE'],
																				     ':P_CDPRODUTO'       => $row['CDPRODUTO'],
																				     ':P_NMPRODUTO'       => $row['NMPRODUTO']));
																	      
					$prodSemErro[] = array('CDPRODUTO' => $row['CDPRODUTO']);
				} else {
					$prodComErro[] = array('CDPRODUTO' => $row['CDPRODUTO'], 'MENSAGEM' => 'Produto ja cadastrado na tabela auxiliar.|');
				}
			}

			
			//commit
		}catch(\Exception $e){
			//rollback
			$prodComErro[] = array('CDPRODUTO' => $row['CDPRODUTO'], "exception" => $e->getMessage());
		}

		if (empty($prodComErro)) {
			$prodComErro = [];	
		}
		if (empty($prodSemErro)) {
			$prodSemErro = [];
		}

		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("prodComErro", $prodComErro));
		$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("prodSemErro", $prodSemErro));
	}
	
/*******************************************************************************
	dbHandle é a função de manipulação do banco de dados.
*******************************************************************************/
	
	public function dbHandle($response, $row) {
		$queryHandle = <<<SQL
			SELECT DTHRLANPED FROM PEDIDO
			WHERE (NRORG = :P_NRORG)
			ORDER BY DTHRLANPED DESC
SQL;

		try {
			$handle = $this->getConnection($row)->fetchAll($queryHandle, array(':P_NRORG' => $row['NRORG']));
														  
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("handle", $handle));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
	}
	
/*******************************************************************************
	verificarPendenciaFinanceira  é  a  requisição  que  verifica  se  o cliente 
	possui pendência financeira.
*******************************************************************************/
	
	public function verificarPendenciaFinanceira($response, $row) {
		$valido = false;
		
		if($row['CDCLIEEXTERNO'] == null){
			// Código externo do cliente não enviado.
		$result = array( "valido" => false , "validation" => array('CDPEDEXTERNO' => $row['PEDEXTERNO'], 'MENSAGEM' => ' Cliente nao enviado no pedido.|'));
		} else {
			$queryClieExt = <<<SQL
				SELECT CDCLIENTE
				  FROM CLIEPEDWEB
				 WHERE (CDCLIEEXTERNO   = :P_CDCLIEEXTERNO  )
				   AND (NRORG           = :P_NRORG          )
SQL;
			$clienteExt = $this->getConnection($row)->fetchAll($queryClieExt, array(':P_CDCLIEEXTERNO' => $row['CDCLIEEXTERNO'],
																		   ':P_NRORG'         => $row['NRORG']));
			// Cliente não encontrado com esse código externo.
			if(empty($clienteExt)){
				$queryClie = <<<SQL1
					SELECT CDCLIENTE
					  FROM CLIEPEDWEB
					 WHERE (CDCLIENTE   = :P_CDCLIEEXTERNO  )
					   AND (NRORG       = :P_NRORG          )
SQL1;
				$cliente = $this->getConnection($row)->fetchAll($queryClie, array(':P_CDCLIEEXTERNO' => $row['CDCLIEEXTERNO'],
																		 ':P_NRORG'         => $row['NRORG']));
				// Cliente não encontrado com esse código interno.
				if(empty($cliente)){
					$response = 'Cliente '.$row['CDCLIEEXTERNO'].' nao cadastrado no sistema';
				} else {
					$row['CDCLIEEXTERNO'] = $cliente[0]['CDCLIENTE'];
					$valido = true;
				}
			} else {
				$row['CDCLIEEXTERNO'] = $clienteExt[0]['CDCLIENTE'];
				$valido = true;
			}
		}
		
		if ($valido == true) {
			$query = <<<SQL2
				SELECT CO.NRORG, CO.DTATUAVENREC, CO.CDFILIAL, CO.NRLANCTONF, CO.VRATUAREC, NF.NRNOTAFISC
				  FROM CONTARECEBER CO, NOTAFISCAL NF, BOLETRECEBER BO
				 WHERE (NF.CDCLIENTE    = :P_CDCLIENTE  )
				   AND (NF.NRORG        = :P_NRORG      )
				   AND (CO.CDFILIAL     = NF.CDFILIAL   )
				   AND (CO.NRLANCTONF   = NF.NRLANCTONF )
				   AND (CO.NRORG        = NF.NRORG      )
				   AND (CO.NRLANBOLREC  = BO.NRLANBOLREC)
				   AND (CO.CDFILIBOLREC = BO.CDFILIAL   )
				   AND (CO.NRORG        = BO.NRORG      )
				   AND (BO.DTVENBOLREC  < SYSDATE       )
				   AND (CO.IDSTATREC    IN    ('A', 'D'))
				   AND (NF.IDSTATUS     IN    ('A', 'E'))
				 ORDER BY CO.NRORG, CO.CDFILIAL, CO.DTATUAVENREC
SQL2;
			
			try {
				$produtos = $this->getConnection($row)->fetchAll($query, array(':P_NRORG'     => $row['NRORG'],
																	  ':P_CDCLIENTE' => $row['CDCLIEEXTERNO']));
				$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("produtos", $produtos));
			} catch (\Exception $e) {
				$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
			}
		}
    }
    
    /** INÍCIO NOVOS METODOS PARA SELLENT **/
    
    /* ok
    * Retorna lista de clientes de acordo com a organização
    */
    public function getCliente($response, $row) {
    	
		try {
			$newConnection = $this->getConnection($row);
			
			$query = "SELECT C.CDCLIENTE AS CLIENT_ID,
						      C.NMFANTCLIE AS CLIENT_NAME,
						      C.NMRAZSOCCLIE AS CLIENT_LEGAL_NAME,
						      E.NRCEPCLIE AS CLIENT_ZIPCODE,
						      E.DSENDECLIE AS CLIENT_ADDRESS,
						      '' AS CLIENT_ADDRESS_NUMBER,
						      E.DSCOMPENDCLI AS CLIENT_ADDRESS_COMPLEMENT,
						      E.CDMUNICIPIO AS CLIENT_CITY,
						      E.SGESTADO AS CLIENT_UF,
						      E.CDPAIS AS CLIENT_COUNTRY,
						      '' AS CLIENT_NEIGHBORHOOD,
						      E.NRTELECLIE AS CLIENT_PHONE,
						      E.DSEMAILCLIE AS CLIENT_EMAIL,
						      '' AS CLIENT_LAST_INVOICE,
						      (SELECT MAX(NRPEDIDO) FROM PEDIDO P 
						      WHERE CDCLIENTE = C.CDCLIENTE) AS CLIENT_LAST_ORDER,
						      C.IDCLIEATIV AS CLIENT_STATUS,
						      C.CDVENDEDOR AS SALESMAN_ID,
						      V.NMFANVEN AS SALESMAN_NAME,
						      C.CDREGIAOPED AS REGION_ID,
						      R.NMREGIAOPED AS REGION,
						      C.CDSEGMER AS SEGMENT_ID,
						      S.DSSEGMER AS SEGMENT,
						      C.CDGRUPCLIE AS CLIENT_GROUP,
						      G.NMGRUPCLIE AS CLIENT_GROUP_NAME,
						      C.DTINCLUSAO AS CLIENT_SINCE,
						      C.NRINSJURCLIE AS CPF_CNPJ,
						      C.NRINSESTCLIE AS IE,
						      (SELECT CDPRECOBASE FROM PRECOBASECLI
						      WHERE C.CDCLIENTE = CDCLIENTE 
						      AND IDPRBASEPRIN = 'S') AS PRICE_TABLE_ID,
						      C.CDMODPGTO AS PAYMENT_FORM_ID,
						      '' AS PAYMENT_TERM_ID,
						      C.IDTPIJURCLIE AS CLIENT_TYPE
						FROM CLIENTE C, ENDECLIE E, VENDEDOR V, REGIAOPED R, SEGMERCADO S, GRUPCLIE G
						WHERE C.IDCLIEATIV = 'S'
						AND C.CDCLIENTE = E.CDCLIENTE
						AND E.IDTPENDECLIE = 'P'
						AND C.CDVENDEDOR = V.CDVENDEDOR (+)
						AND C.CDREGIAOPED = R.CDREGIAOPED (+)
						AND C.CDSEGMER = S.CDSEGMER (+)
						AND C.CDGRUPCLIE = G.CDGRUPCLIE (+)
						AND C.NRORG = :P_NRORG";
				 
			$cliente = $newConnection->fetchAll($query, array(':P_NRORG' => $row['NRORG']));
			
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("cliente", $cliente));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    /* ok
    * Retorna lista de produtos de acordo com a organização
    */
    public function getProduto($response, $row) {
    	
		try {
			$newConnection = $this->getConnection($row);
			
			$query = "SELECT P.IDPRODATIVPR AS ACTIVE,
					        P.CDARVPROD AS PRODUCT_ID,
					        P.NMPRODUTO AS PRODUCT_DESC,
					        :P_CDPRECOBASE AS PRICE_TABLE,
					        '' AS IPI_VALUE,
					        '' AS CATEGORY_ID,
					        '' AS CATEGORY,
					        '' AS STOCK,
					        '' AS COST,
					        '' AS TYPE,
					        P.SGUNIDADE AS UNIT,
					        I.CDEANPROD AS EAN,
					        P.CDPRODNCM AS NCM,
					        VRPESOLIQUPR AS WEIGHT_NET,
					        VRPESOBRUTPR AS WEIGHT_GROSS,
					        P.CDPRODINTE AS CODE,
					        BUSCA_PRECO_PED('', P.CDARVPROD, '', :P_CDPRECOBASE, SYSDATE, '') AS PRICE,
					        '' AS MINIMUM,
					        P.VRVOLMED AS MULTIPLE,
					        '' AS IMPORTED,
					        '' AS ALLOW_ECOMMERCE
					FROM PRODUTO P, INFADICPROD I
					WHERE P.NRORG = :P_NRORG
					AND P.CDNVPRODUTO = (SELECT MAX(CDNVPRODUTO) FROM PRODUTO)
					AND P.CDPRODUTO = I.CDPRODUTO (+)
					AND P.IDPRODATIVPR = 'S'
					AND BUSCA_PRECO_PED('', P.CDARVPROD, '', :P_CDPRECOBASE, SYSDATE, '') > 0
					AND (P.CDARVPROD BETWEEN :P_CDPRODINI AND RPAD(:P_CDPRODFIN, 20, 'z') OR (:P_TCDPROD = 'T'))";
			
			$produto = $newConnection->fetchAll($query, array(':P_NRORG' => $row['NRORG'],
															  ':P_CDPRECOBASE' => $row['CDPRECOBASE'],
															  ':P_CDPRODINI' => isset($row['CDPRODINI']) ? $row['CDPRODINI'] : '',
															  ':P_CDPRODFIN' => isset($row['CDPRODFIN']) ? $row['CDPRODFIN'] : '',
															  ':P_TCDPROD' => isset($row['TCDPROD']) ? $row['TCDPROD'] : ''));
			
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("produto", $produto));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    /* OK
    * Retorna lista de pedidos de acordo com [NRORG, CDFILIAL, DTINICIAL e DTFINAL]
    */
    public function getVRTOTALPED($row, $nrpedido){
    	try{
    		
    		$newConnection = $this->getConnection($row);
    		$query = "SELECT P.*,
							  C.NMFANTCLIE,
							  C.NMRAZSOCCLIE,
							  C.IDTPIJURCLIE,
							  C.NRINSJURCLIE,
							  E.DSEMAILCLIENFE,
							  V.NMFANVEN,
							  M.DSMODPGTO,
							  T.NMFANTTRAN,
							  PB.DSPRECOBASE,
							  TP.NMTIPOOPER,
							  F.NMFILIAL,
							  FD.NMFILIAL AS FILIDEST,
							  R.NMROTATRANS,
							  C.CDTIPODESC,
							  D.NMTIPODESC,
							  D.QTPRITPDESC,
							  D.QTSEGTPDESC,
							  D.QTTERTPDESC,
							  D.QTQUATPDESC,
							  D.QTQUITPDESC,
							  D.QTSEXTPDESC,
							  D.QTSETTPDESC,
							  D.QTOITTPDESC,
							  HIS.NRHISIMPPEDEEEP,
							  TP.IDORIGDESTOP,
							  TO_CHAR(TOTAL.VRTOTALPED) VRTOTALPED,
							  TOTAL.VRITEM AS VRTOTPEDLIQ,
							  O.TXOBSPED,
							  O.TXOBSPED_CLOB
							FROM PEDIDO P,
							  CLIENTE C,
							  TRANSPORT T,
							  VENDEDOR V,
							  MODPGTO M,
							  ENDECLIE E,
							  PRECOBASE PB,
							  TIPOOPERAC TP,
							  FILIAL F,
							  FILIAL FD,
							  ROTATRANS R,
							  TIPODESC D,
							  HISIMPITEMEEEPC HIS,
							  OBSPEDIDO O,
							  (SELECT I.NRORG,
							    I.CDFILIAL,
							    I.NRPEDIDO,
							    (NVL(I.VRITEM,0) + NVL(E.VRENCARGO,0) + NVL(IM.VRIMPOSTO,0)) VRTOTALPED,
							    I.VRITEM
							  FROM
							    (SELECT I.NRORG,
							      I.CDFILIAL,
							      I.NRPEDIDO,
							      SUM((NVL(I.QTITEMPED,0) * NVL(I.VRPREUNITPED,0)) - NVL(I.VRDESITPED,0)) VRITEM
							    FROM ITEMPEDIDO I
							    GROUP BY I.NRORG,
							      I.NRPEDIDO,
							      I.CDFILIAL
							    ) I,
							    (SELECT E.NRORG,
							      E.CDFILIAL,
							      E.NRPEDIDO,
							      SUM(
							      CASE EN.IDENCARGO
							        WHEN 'A'
							        THEN TO_CHAR(NVL(E.VRENCARGOPED,0))
							        WHEN 'D'
							        THEN TO_CHAR(NVL(E.VRENCARGOPED,0) * -1)
							        ELSE '0'
							      END) VRENCARGO
							    FROM ENCARGOPED E,
							      ENCARGO EN
							    WHERE E.CDENCARGO = EN.CDENCARGO
							    AND E.NRORG       = EN.NRORG
							    GROUP BY E.NRORG,
							      E.CDFILIAL,
							      E.NRPEDIDO
							    ) E,
							    (SELECT IP.NRORG,
							      IP.CDFILIAL,
							      IP.NRPEDIDO,
							      SUM(
							      CASE IM.IDTRATIMPO
							        WHEN 'A'
							        THEN TO_CHAR(NVL(IP.VRACREDESCITPED,0))
							        WHEN 'D'
							        THEN TO_CHAR(NVL(IP.VRACREDESCITPED,0) * -1)
							        ELSE '0'
							      END) VRIMPOSTO
							    FROM IMPOSTO IM,
							      IMPITEMPEDIDO IP
							    WHERE IP.CDIMPOSTO = IM.CDIMPOSTO
							    AND IP.NRORG       = IM.NRORG
							    GROUP BY IP.NRORG,
							      IP.CDFILIAL,
							      IP.NRPEDIDO
							    ) IM
							  WHERE I.CDFILIAL = E.CDFILIAL (+)
							  AND I.NRPEDIDO   = E.NRPEDIDO (+)
							  AND I.NRORG      = E.NRORG (+)
							  AND I.CDFILIAL   = IM.CDFILIAL (+)
							  AND I.NRPEDIDO   = IM.NRPEDIDO (+)
							  AND I.NRORG      = IM.NRORG (+)
							  ) TOTAL
							WHERE (P.CDVENDEDOR         = V.CDVENDEDOR)
							AND (P.NRORG                = V.NRORG)
							AND (P.CDCLIENTE            = C.CDCLIENTE)
							AND (P.NRORG                = C.NRORG)
							AND (P.CDMODPGTO            = M.CDMODPGTO)
							AND (P.NRORG                = M.NRORG)
							AND (P.CDFILIALPED          = FD.CDFILIAL (+))
							AND (P.NRORG                = FD.NRORG (+))
							AND (P.CDFILIAL             = F.CDFILIAL (+))
							AND (P.NRORG                = F.NRORG (+))
							AND (P.NRORG                = O.NRORG (+))
							AND (P.CDFILIAL             = O.CDFILIAL (+))
							AND (P.NRPEDIDO             = O.NRPEDIDO (+))
							AND (P.CDPRECOBASE          = PB.CDPRECOBASE (+))
							AND (P.NRORG                = PB.NRORG (+))
							AND (P.CDTIPOOPER           = TP.CDTIPOOPER (+))
							AND (P.NRORG                = TP.NRORG (+))
							AND (TP.IDENTRSAIDOP(+)     = 'S')
							AND (T.NRINSJURTRAN (+)     = P.NRINSJURTRAN)
							AND (T.IDTPIJURTRAN (+)     = P.IDTPIJURTRAN)
							AND (P.NRORG                = T.NRORG (+))
							AND (C.CDCLIENTE            = E.CDCLIENTE (+))
							AND (C.NRORG                = E.NRORG (+))
							AND (E.IDTPENDECLIE (+)     = 'P')
							AND (C.CDTIPODESC           = D.CDTIPODESC (+))
							AND (C.NRORG                = D.NRORG (+))
							AND (P.CDROTATRANSPED       = R.CDROTATRANS(+))
							AND (P.NRORG                = R.NRORG (+))
							AND (HIS.CDFILIMPPEDEEEP(+) = P.CDFILIAL)
							AND (HIS.NRPEDIDO(+)        = P.NRPEDIDO)
							AND (P.NRORG                = HIS.NRORG (+))
							AND P.CDFILIAL              = TOTAL.CDFILIAL (+)
							AND P.NRPEDIDO              = TOTAL.NRPEDIDO (+)
							AND P.NRORG                 = TOTAL.NRORG (+)
							AND P.CDFILIAL				= :P_CDFILIAL
							AND P.NRPEDIDO				= :P_NRPEDIDO
							ORDER BY P.NRPEDIDO DESC";
				 
			$pedido = $newConnection->fetchAll($query, array(':P_CDFILIAL'	=> $row['CDFILIAL'],
															':P_NRPEDIDO'	=> $nrpedido));
			
			return $pedido;
    	} catch (\Exception $e) {
			// $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    public function getResultPedido($row){
    	try{
    		
    		$newConnection = $this->getConnection($row);
    		
    		$query = "SELECT P.NRPEDIDO AS ORDER_ID, /*OBRIGATORIO*/
					        P.DTPEDIDO AS ORDER_DATE, /*OBRIGATORIO*/
					        DECODE(P.IDTIPOPEDIDO, 1, 'Pedido', 2, 'Orçamento') AS ORDER_TYPE,
					        P.CDVENDEDOR AS SELLER_ID,
					        V.NMFANVEN AS SELLER_NAME,
					        '' AS SELLER_REGION_CODE,
					        '' AS SELLER_REGION_DESCRIPTION,
					        P.CDCLIENTE AS CLIENT_ID, /*OBRIGATORIO*/
					        C.NMFANTCLIE AS CLIENT_NAME, /*OBRIGATORIO*/
					        C.NMRAZSOCCLIE AS CLIENT_LEGAL_NAME,
					        D.DSENDEPED AS CLIENT_ADDRESS,
					        '' AS CLIENT_ADDRESS_NUMBER,
					        '' AS CLIENT_NEIGHBORHOOD,
					        D.NRCEPPED AS CLIENT_ZIPCODE,
					        C.DTINCLUSAO AS CLIENT_SINCE,
					        D.CDFILIAL AS CLIENT_BRANCH,
					        '' AS CLIENT_PARENT,
					        D.NRINSJURPED AS CLIENT_CNPJ,
					        '' AS CLIENT_EMAIL,
					        D.NRTELEPED AS CLIENT_PHONE,
					        D.SGESTADOPED AS STATE,
					        D.NMMUNIPED AS CITY_NAME,
					        '' AS INVOICE_NUMBER,
					        '' AS LAST_INVOICE_DATE,
					        P.DTPEDIDO AS INVOICE_DATE,
					        '' AS CATEGORY_ID,
					        '' AS CATEGORY_NAME,
					        '' AS SEGMENT,
					        '' AS SEGMENT_ID,
					        '' AS SHIPPING_DATE,
					        '' AS INVOICES_LATE,
					        C.CDGRUPCLIE AS CLIENT_GROUP,
					        '' AS CLIENT_GROUP_NAME,
					        '' AS COMMISSION,
					        P.IDSITPEDIDO AS STATUS,
					        P.CDMODPGTO AS PAYMENT_METHOD_ID,
					        P.CDFORMPGTO AS PAYMENT_TERM_ID,
					        '' AS REFERENCE_ID,
					        P.DTENTPED AS DELIVERY_DATE,
					        '' AS FREIGHT_VALUE,
					        P.NREXPEDIDO AS CODE
					FROM PEDIDO P, CLIENTE C, VENDEDOR V, DADOSENDPED D
					WHERE P.CDFILIAL = :P_CDFILIAL
					AND P.CDCLIENTE = C.CDCLIENTE
					AND P.CDVENDEDOR = V.CDVENDEDOR
					AND P.NRPEDIDO = D.NRPEDIDO
					AND P.NRORG = :P_NRORG
					AND P.DTPEDIDO BETWEEN :P_DTINICIAL AND :P_DTFINAL
					ORDER BY P.NRPEDIDO DESC";
				 
			$pedido = $newConnection->fetchAll($query, array(':P_CDFILIAL'	=> $row['CDFILIAL'],
															':P_NRORG'		=> $row['NRORG'],
															':P_DTINICIAL'	=> $row['DTINICIAL'],
															':P_DTFINAL'	=> $row['DTFINAL']));
			
			return $pedido;
    	} catch (\Exception $e) {
			// $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    } 
    
    public function getResultItempedido($row, $nrpedido){
    	try{
    		
    		$newConnection = $this->getConnection($row);
    		
    		$query = "SELECT I.NRITEMPED AS ITEM_NUMBER,
						      I.CDPRODUTO AS PRODUCT_ID,
						      P.NMPRODUTO AS PRODUCT_DESCRIPTION,
						      '' AS PRODUCT_TYPE,
						      I.QTITEMPED AS QTY,
						      I.VRPREUNITPED AS ITEM_VALUE,
						      I.VRPREUNITPED AS ITEM_NET_VALUE,
						      '' AS COST,
						      I.VRDESITPED AS DISCOUNT
						FROM ITEMPEDIDO I, PRODUTO P
						WHERE I.CDFILIAL = :P_CDFILIAL
						AND I.NRPEDIDO = :P_NRPEDIDO
						AND I.CDPRODUTO = P.CDPRODUTO
						AND I.NRORG = :P_NRORG";
				 
			$itempedido = $newConnection->fetchAll($query, array(':P_CDFILIAL'	=> $row['CDFILIAL'],
																':P_NRPEDIDO'	=> $nrpedido,
																':P_NRORG'		=> $row['NRORG']));
															
			return $itempedido;
    	} catch (\Exception $e) {
			// $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    public function getPedido($response, $row) {
		try {
			$pedidos = $this->getResultPedido($row);
			$newPedidos = array();
			foreach($pedidos as $pedido){
				$pedidoCompleta = $this->getVRTOTALPED($row, $pedido['ORDER_ID']);
				
				$vrtotalped = floatval(str_replace(",",".", $pedidoCompleta[0]['VRTOTALPED']));
				
				$pedido['ORDER_VALUE'] = $vrtotalped;
				$pedido['INVOICE_VALUE'] = $vrtotalped;
				
				$pedido['ITENS'] = $this->getResultItempedido($row, $pedido['ORDER_ID']);
				
				array_push($newPedidos, $pedido);
			}
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("pedido", $newPedidos));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    /* OK
    * Retorna lista de transportadoras de acordo com a organização
    */
    public function getTransportadora($response, $row) {
    	
		try {
			$newConnection = $this->getConnection($row);

				$query = <<<SQL
						SELECT T.NRINSJURTRAN AS ID,
							      T.NMRAZSOCTRAN AS LEGAL_NAME,
							      T.NMFANTTRAN AS NAME,
							      T.NRINSJURTRAN AS CNPJ,
							      T.DSENDETRAN AS ADDRESS,
							      '' AS NEIGHBORHOOD,
							      '' AS "NUMBER",
							      T.NRCEPTRAN AS ZIP_CODE,
							      M.NMMUNICIPIO AS CITY,
							      E.NMESTADO AS STATE,
							      '' AS COMPLEMENT,
							      T.NRTELETRAN AS PHONE,
							      T.DSEMAILTRANSPNFE AS EMAIL,
							      '' AS OBSERVATION
							FROM TRANSPORT T, PAIS P, ESTADO E, MUNICIPIO M
							WHERE T.CDPAIS = P.CDPAIS
							AND T.SGESTADO = E.SGESTADO
							AND T.CDMUNICIPIO = M.CDMUNICIPIO
							AND T.NRORG = :P_NRORG
SQL;
				 
			$transportadora = $newConnection->fetchAll($query, array(':P_NRORG' => $row['NRORG']));
			
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("transportadora", $transportadora));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    /* OK
    * Retorna lista de tabelas de preço de acordo com [NRORG, CDPRECOBASE]
    */
    public function getPreco($response, $row) {
    	
		try {
			$newConnection = $this->getConnection($row);
			
			$query = "SELECT CDPRECOBASE AS ID, 
					        DSPRECOBASE AS DESCRIPTION,
					        '' AS PRODUCT_ID,
					        '' AS PRICE,
					        DTINCLUSAO AS CREATED_AT,
					        DTULTATU AS UPDATED_AT     
					FROM PRECOBASE
					WHERE NRORG = :P_NRORG";
				 
			$tabelaPreco = $newConnection->fetchAll($query, array(':P_NRORG' => $row['NRORG']));
			
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("tabelaPreco", $tabelaPreco));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    
    /* OK
    * Retorna lista de modalidades de acordo com a organização
    */
    public function getModalidade($response, $row) {
    	
		try {
			$newConnection = $this->getConnection($row);
			
			$query = "SELECT CDMODPGTO AS ID,
					      DSMODPGTO AS DESCRIPTION,
					      IDATIVO AS ACTIVE
					FROM MODPGTO
					WHERE NRORG = :P_NRORG";
				 
			$modalidade = $newConnection->fetchAll($query, array(':P_NRORG' => $row['NRORG']));
			
			$response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet("modalidade", $modalidade));
		} catch (\Exception $e) {
			$response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 0));
		}
    }
    /** FIM NOVOS METODOS PARA SELLENT **/
    
}